@@ -4,6 +4,8 @@
 ;;
 ;; Author: Masatake YAMATO <jet@gyve.org>
 ;; Created: Tue May 13 19:12:23 2003
+;; Version: $Id: context-skk.el,v 1.15 2011/06/10 12:23:46 skk-cvs Exp $
+;; Last Modified: $Date: 2011/06/10 12:23:46 $
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -172,6 +174,12 @@
   :type 'hook
   :group 'context-skk)
 
+;;;###autoload
+(defcustom context-skk-mode-off-message "[context-skk] $BF|K\8lF~NO(B off"
+  "*`context-skk-mode' $B$,(B off $B$K$J$C$?$H$-$K%(%3!<%(%j%"$KI=<($9$k%a%C%;!<%8!#(B"
+  :type 'string
+  :group 'context-skk)
+
 ;;
 ;; Minor mode definition
 ;;
@@ -225,7 +233,7 @@
 
 (defun context-skk-insert ()
   "skk-latin-mode $B$r(B on $B$K$7$?>e(B `this-command-keys' $B$KBP$9$k4X?t$r8F$S=P$7D>$9!#(B"
-  (message "[context-skk] $BF|K\8lF~NO(B off")
+  (message "%s" context-skk-mode-off-message)
   (skk-latin-mode t)
   (let* ((keys (this-command-keys))
 	 ;; `this-command-keys' $B$,(B tab $B$rJV$7$?$H$-$J$I(B function-key-map $B$d(B
