@@ -5,10 +5,10 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-annotation.el,v 1.171 2010/12/12 11:09:19 skk-cvs Exp $
+;; Version: $Id: skk-annotation.el,v 1.185 2011/06/24 23:58:03 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Oct. 27, 2000.
-;; Last Modified: $Date: 2010/12/12 11:09:19 $
+;; Last Modified: $Date: 2011/06/24 23:58:03 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -252,6 +252,7 @@
     (erase-buffer)))
 
 (defun skk-annotation-insert (annotation)
+  "`skk-annotation-buffer' $B$K(B ANNOTATION $B$rA^F~$9$k(B"
   (with-current-buffer (get-buffer-create skk-annotation-buffer)
     (skk-annotation-erase-buffer)
     (setq buffer-read-only nil)
@@ -262,11 +263,12 @@
 
 ;;;###autoload
 (defun skk-annotation-get (annotation)
-  (if (string= annotation "")
-      ""
-    (if (eq (aref annotation 0) ?*)
-	(substring annotation 1)
-      annotation)))
+  (cond ((string= annotation "")
+	 "")
+	((eq (aref annotation 0) ?*)
+	 (substring annotation 1))
+	(t
+	 annotation)))
 
 ;;;###autoload
 (defun skk-annotation-find-and-show (pair)
@@ -444,33 +446,67 @@
 
 ;;;###autoload
 (defun skk-annotation-message (&optional situation)
+  "
+$B%*%W%7%g%J%k0z?t(B SITUATION $B$,(B $B%7%s%\%k(B annotation $B$G$"$l$P!"(B"
   (when (and skk-verbose
 	     (not (or skk-isearch-switch
 		      (skk-in-minibuffer-p))))
     (unless skk-annotation-wikipedia-message
-      (let* ((key (key-description skk-annotation-wikipedia-key))
-	     (string "{$B$I$N(BWiki?}")
-	     (i 0)
-	     source)
+      (let ((key (key-description skk-annotation-wikipedia-key))
+	    (string "")
+	    list new)
 	(when (equal key "TAB")
 	  (setq key "C-i"))
-	(while (setq source (nth i skk-annotation-wikipedia-sources))
-	  (setq string (format "%s[C-%d %s]%s " string (1+ i) key source))
-	  (setq i (1+ i)))
-	(setq skk-annotation-wikipedia-message string)))
+	(setq list
+	      (split-string
+	       (dotimes (i (length skk-annotation-wikipedia-sources) string)
+		 (setq string
+		       (format "%s[C-%d %s]%s  "
+			       string
+			       (1+ i)
+			       key
+			       (nth i skk-annotation-wikipedia-sources))))
+	       "  "))
+	(dolist (x list)
+	  (let* ((y (split-string x "]"))
+		 (s1 (car y))
+		 (s2 (nth 1 y)))
+	    (setq new (concat new
+			      (propertize (concat s1 "]") 'face
+					  'skk-verbose-kbd-face)
+			      s2 " "))))
+	(setq skk-annotation-wikipedia-message
+	      (concat (propertize "{$B$I$N(BWiki?}" 'face
+				  'skk-verbose-intention-face)
+		      new))))
+    ;;
     (unless skk-annotation-message
       (let ((key-copy (or (key-description skk-annotation-copy-key)
 			  "$BL$Dj5A(B"))
 	    (key-wiki (or (key-description skk-annotation-wikipedia-key)
 			  "$BL$Dj5A(B"))
 	    (key-browse (or (key-description skk-annotation-browse-key)
-			    "$BL$Dj5A(B")))
+			    "$BL$Dj5A(B"))
+	    list new)
 	(when (equal key-wiki "TAB")
 	  (setq key-wiki "C-i"))
+	(setq list
+	      (split-string
+	       (format "[%s]$B%3%T!<(B  [%s]URL$B%V%i%&%:(B  [%s]$B%G%U%)%k%H(BWiki$B;2>H(B"
+		       key-copy key-browse key-wiki) "  "))
+	(dolist (x list)
+	  (let* ((y (split-string x "]"))
+		 (s1 (car y))
+		 (s2 (nth 1 y)))
+	    (setq new (concat new
+			      (propertize (concat s1 "]") 'face
+					  'skk-verbose-kbd-face)
+			      s2 " "))))
 	(setq skk-annotation-message
-	      (format "\
-\{$B%"%N%F!<%7%g%s(B}[%s]$B%3%T!<(B [%s]URL$B%V%i%&%:(B [%s]$B%G%U%)%k%H(BWiki$B;2>H(B"
-		      key-copy key-browse key-wiki))))
+	      (concat (propertize "{$B%"%N%F!<%7%g%s(B}" 'face
+				  'skk-verbose-intention-face)
+		      new))))
+    ;;
     (condition-case nil
 	(cond ((eq situation 'annotation)
 	       (if (skk-sit-for skk-verbose-wait)
@@ -486,6 +522,7 @@
 			 (setq i (1+ i))))
 		     (message nil))
 		 nil))
+	      ;;
 	      (t
 	       (when (skk-sit-for skk-verbose-wait)
 		 (message "%s" skk-annotation-wikipedia-message))))
@@ -536,26 +573,19 @@
 		(t
 		 (split-window-vertically)))
 	  ;;
-	  (display-buffer skk-annotation-buffer)
+	  (skk-fit-window
+	   (display-buffer skk-annotation-buffer))
 	  (when minibuf-p
 	    (select-window (minibuffer-window)))
 	  ;;
-	  (unless (eval-when-compile (and (featurep 'xemacs)
-					  (= emacs-major-version 21)
-					  (<= emacs-minor-version 4)))
-	    (save-selected-window
-	      (pop-to-buffer skk-annotation-buffer)
-	      (fit-window-to-buffer)))
-	  ;;
 	  (skk-annotation-message 'annotation)
 	  ;;
 	  (setq event (next-command-event))
-	  (when (skk-key-binding-member
-		 (skk-event-key event)
-		 '(key-board-quit
-		   skk-kanagaki-bs
-		   skk-kanagaki-esc)
-		 skk-j-mode-map)
+	  (when (skk-key-binding-member (skk-event-key event)
+					'(key-board-quit
+					  skk-kanagaki-bs
+					  skk-kanagaki-esc)
+					skk-j-mode-map)
 	    (signal 'quit nil))
 	  (skk-unread-event event)))
     (quit
@@ -612,9 +642,9 @@
 ;;;###autoload
 (defun skk-annotation-add (&optional no-previous-annotation)
   "$B:G8e$K3NDj$7$?8l$K(B annotation $B$rIU$1$k!#(B
-$B4{$KIU$1$i$l$F$$$k(B annotation $B$,$"$l$P$=$l$rJT=8%P%C%U%!$K=PNO$9$k!#(B
-no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj2D(B\)
-$B4{$KIU$1$i$l$F$$$k(B annotation $B$rJT=8%P%C%U%!$K=PNO$7$J$$!#(B"
+$B4{$K(B annotation $B$,IU$1$i$l$F$$$l$P!"$=$l$rJT=8%P%C%U%!$K=PNO$9$k!#(B
+NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-add])
+$B$9$k$H!"4{$KIU$1$i$l$F$$$k(B annotation $B$rJT=8%P%C%U%!$K=PNO$7$J$$!#(B"
   (interactive "P")
   (save-match-data
     (skk-kakutei)
@@ -805,7 +835,7 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 			skk-okuri-ari-max nil)
 		    t nil)
 	    (goto-char (match-beginning 1))
-	    (set-marker eol (skk-save-point (end-of-line) (point)))
+	    (set-marker eol (line-end-position))
 	    (when (string-match ";" word)
 	      (setq word (substring word 0 (match-beginning 0))))
 	    (when (re-search-forward
@@ -850,6 +880,7 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
   "Wiktionary/Wikipedia $B$N(B WORD $B$KAjEv$9$k5-;v$+$i%"%N%F!<%7%g%s$r<hF@$9$k!#(B"
   (let ((sources (or sources skk-annotation-wikipedia-sources))
 	source
+	words
 	(string "")
 	(note nil))
     ;; sources $B$K;XDj$5$l$?=gHV$K;2>H$9$k(B
@@ -858,37 +889,34 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 	    (while (and (or (not note) (equal note ""))
 			sources)
 	      (setq source (car sources))
-	      ;; Wiktionary $B$G$O$=$N$^$^!"(BWikipedia $B$G$OBh(B 1 $BJ8;z$N$_(B upcase
-	      (setq note (skk-annotation-wikipedia-1 word source
-						     (= 1 (length sources))))
-	      (when (equal note "")
-		(setq note nil))
-	      ;;
-	      (when (and (null note)
-			 (memq source '(en.wiktionary ja.wiktionary))
-			 (skk-ascii-char-p (aref word 0))
-			 (not (skk-lower-case-p (aref word 0))))
-		;; Wiktionary $B$G$9$Y$F(B downcase $B$9$k>l9g(B
-		;; e.g. FOO or Foo -> foo
-		(setq note (skk-annotation-wikipedia-1
-			    (downcase word)
-			    source
-			    (= 1 (length sources))))
-		(when (equal note "")
-		  (setq note nil)))
-	      ;;
-	      (sleep-for 0.01) ; $B$3$l$,$J$$$H;_$^$k$3$H$"$j(B
-	      ;;
-	      (when (and (null note)
-			 (skk-ascii-char-p (aref word 0))
-			 (>= (length word) 2)
+	      (cond
+	       ((memq source '(en.wiktionary ja.wiktionary))
+		(setq words (list word))
+		(when (skk-ascii-char-p (aref word 0))
+		  (cond
+		   ((skk-lower-case-p (aref word 0))
+		    ;; foo -> Foo, FOO
+		    (setq words (append words (list (upcase-initials word))))
+		    (if (>= (length word) 2)
+			(setq words (append words (list (upcase word))))))
+		   ((and (>= (length word) 2)
 			 (skk-lower-case-p (aref word 1)))
-		;; $B$9$Y$F(B upcase $B$9$k>l9g(B
-		;; e.g. skk or Skk -> SKK
-		(setq note (skk-annotation-wikipedia-1
-			    (upcase word)
-			    source
-			    (= 1 (length sources))))
+		    ;; Foo -> foo, FOO
+		    (setq words (append words (list (downcase word) (upcase word)))))
+		   (t
+		    ;; FOO -> foo, Foo
+		    (setq words (append words (list (downcase word))))
+		    (if (>= (length word) 2)
+			(setq words (append words
+					    (list (upcase-initials word)))))))))
+     (t
+      (setq words (list (upcase-initials word)))
+      (if (>= (length word) 2)
+	  (setq words (append words (list (upcase word)))))))
+	      (while (and (not note) words)
+		(setq note (skk-annotation-wikipedia-1 (car words) source t))
+		(sleep-for 0.01) ; $B$3$l$,$J$$$H;_$^$k$3$H$"$j(B
+		(setq words (cdr words))
 		(when (equal note "")
 		  (setq note nil)))
 	      ;;
@@ -921,14 +949,15 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
     (insert "_"))
   (html2text-delete-tags p1 p2 (1+ p3) (1+ p4)))
 
-(defun skk-annotation-wikipedia-1 (word source last)
+(defun skk-annotation-wikipedia-1 (word source &optional preserve-case)
   "Wiktionary/Wikipedia $B$N(B WORD $B$KAjEv$9$k5-;v$r<B:]$K%@%&%s%m!<%I$7$FD4$Y$k!#(B
 $B3:Ev%Z!<%8(B (html) $B$r%@%&%s%m!<%I$9$k5!G=$O(B Emacs $B$KIUB0$N(B URL $B%Q%C%1!<%8$K0M(B
 $B$k!#(B"
   (require 'html2text)
   (require 'url)
   ;;
-  (setq word (skk-annotation-wikipedia-normalize-word word source))
+  (setq word (skk-annotation-wikipedia-normalize-word word source
+						      preserve-case))
   ;;
   (let ((cache-buffer (format " *skk %s %s" source word))
 	;; html2text $B$,@5$7$/07$($J$$(B tag $B$O0J2<$N%j%9%H$K;XDj$9$k(B
@@ -940,16 +969,21 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 	 (append '(("sup" . skk-annotation-wikipedia-clean-sup)
 		   ("sub" . skk-annotation-wikipedia-clean-sub))
 		 html2text-format-tag-list))
+	(url-retrieve-func
+	 (if (fboundp 'url-queue-retrieve)
+	     #'url-queue-retrieve
+	   #'url-retrieve))
 	buf buffer)
     (if (get-buffer cache-buffer)
 	(with-current-buffer cache-buffer
 	  (buffer-string))
       ;; $B%-%c%C%7%e$,$J$$>l9g(B
-      (setq buffer (url-retrieve (skk-annotation-generate-url
-				  "http://%s.org/wiki/%s"
-				  source word)
-				 #'skk-annotation-wikipedia-retrieved
-				 (list (list source))))
+      (setq buffer (funcall url-retrieve-func
+			    (skk-annotation-generate-url
+			     "http://%s.org/wiki/%s"
+			     source word)
+			    #'skk-annotation-wikipedia-retrieved
+			    (list (list source))))
       (while (not buf)
 	(setq buf (catch 'skk-annotation-wikipedia-retrieved
 		    (condition-case nil
@@ -1484,8 +1518,8 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 							      start end)
   "$BA*BrNN0h$^$?$O%]%$%s%H0LCV$NC18l$r(B Wikipedia/Wikitionary $B$GD4$Y$k!#(B
 $BNN0h$,A*Br$5$l$F$$$J$1$l$PC18l$N;O$a$H=*$o$j$r?dB,$7$FD4$Y$k!#(B
-$BD4$Y$?7k2L$r(B skk-annotation-show-as-message $B$,(B Non-nil $B$G$"$l$P%(%3!<%(%j%"$K!"(B
-nil $B$G$"$l$PJL(B window $B$KI=<($9$k!#(B"
+$BD4$Y$?7k2L$r(B `skk-annotation-show-as-message' $B$,(B Non-nil $B$G$"$l$P%(%3!<%(%j%"(B
+$B$K!"(Bnil $B$G$"$l$PJL(B window $B$KI=<($9$k!#(B"
   (interactive (cons (prefix-numeric-value current-prefix-arg)
 		     (cond
 		      ((skk-region-active-p)
@@ -1530,20 +1564,22 @@ nil $B$G$"$l$PJL(B window $B$KI=<($9$k!#(B"
      (error "%s" "$B?7$7$$(B URL $B%Q%C%1!<%8$,I,MW$G$9(B")))
   (if (skk-annotation-url-package-available-p)
       (apply #'format format-string
-	     (mapcar #'(lambda (element)
-			 (if (stringp element)
-			     (url-hexify-string element)
-			   element))
+	     (mapcar (lambda (element)
+		       (if (stringp element)
+			   (url-hexify-string element)
+			 element))
 		     args))
     (error "%s" "URL $B%Q%C%1!<%8$^$?$O(B Mule-UCS $B$,MxMQ$G$-$^$;$s(B")))
 
-(defun skk-annotation-wikipedia-normalize-word (word &optional method)
+(defun skk-annotation-wikipedia-normalize-word (word &optional method
+						     preserve-case)
   ;; $B%9%Z!<%9$O(B %20 $B$G$O$J$/!"%"%s%@!<%9%3%"$KJQ49$9$k(B
   (replace-regexp-in-string
    " " "_"
    (cond
     ((memq method '(ja.wiktionary en.wiktionary))
-     (if (and (> (length word) 1)
+     (if (and (not preserve-case)
+	      (> (length word) 1)
 	      (skk-ascii-char-p (aref word 0))
 	      (skk-lower-case-p (aref word 1)))
 	 ;; $BFsJ8;z$a$,(B lower case $B$J$i(B downcase
