@@ -4,10 +4,10 @@
 
 ;; Author: ONODA Arata <onoto@ma.nma.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-azik.el,v 1.8 2010/09/10 14:23:31 skk-cvs Exp $
+;; Version: $Id: skk-azik.el,v 1.9 2010/11/24 12:22:27 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Jan. 9, 2002
-;; Last Modified: $Date: 2010/09/10 14:23:31 $
+;; Last Modified: $Date: 2010/11/24 12:22:27 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -233,7 +233,7 @@
     ("kj" nil ("$B%/%s(B" . "$B$/$s(B"))
     ("kk" nil ("$B%-%s(B" . "$B$-$s(B"))
     ("kl" nil ("$B%3%s(B" . "$B$3$s(B"))
-    ("km" nil ("$B%-(B" . "$B$-(B"))
+    ("km" nil ("$B%+%b(B" . "$B$+$b(B"))
     ("kn" nil ("$B%+%s(B" . "$B$+$s(B"))
     ("kp" nil ("$B%3%&(B" . "$B$3$&(B"))
     ("kq" nil ("$B%+%$(B" . "$B$+$$(B"))
@@ -454,7 +454,7 @@
     ("vz" nil ("$B%t%!%s(B" . "$B$&!+$!$s(B"))
     ("wA" nil ("$B%n(B" . "$B$n(B"))
     ("wd" nil ("$B%&%'%s(B" . "$B$&$'$s(B"))
-    ("wf" nil ("$B%o(B" . "$B$o(B"))
+    ("wf" nil ("$B%o%$(B" . "$B$o$$(B"))
     ("wha" nil ("$B%&%!(B" . "$B$&$!(B"))
     ("whe" nil ("$B%&%'(B" . "$B$&$'(B"))
     ("whi" nil ("$B%&%#(B" . "$B$&$#(B"))
