@@ -6,9 +6,9 @@
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Author: IRIE Tetsuya <irie@t.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-dcomp.el,v 1.68 2010/09/11 14:56:51 skk-cvs Exp $
+;; Version: $Id: skk-dcomp.el,v 1.72 2011/06/01 13:38:54 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/09/11 14:56:51 $
+;; Last Modified: $Date: 2011/06/01 13:38:54 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -136,7 +136,7 @@
        (< skk-dcomp-start-point skk-dcomp-end-point)))
 
 (defun skk-dcomp-cleanup-buffer ()
-  (skk-dcomp-multiple-hide)
+  (skk-delete-overlay skk-dcomp-multiple-overlays)
   (when (and (or skk-dcomp-activate
 		 skk-dcomp-multiple-activate)
 	     (skk-dcomp-marked-p))
@@ -188,12 +188,11 @@
 	 (message nil))))
     (when (and (skk-dcomp-multiple-activate-p)
 	       (skk-dcomp-multiple-available-p))
-      (skk-dcomp-multiple-show
-       (skk-dcomp-multiple-get-candidates
-	(and (string= skk-dcomp-multiple-key
-		      (buffer-substring-no-properties
-		       skk-henkan-start-point (point)))
-	     (string= skk-dcomp-multiple-prefix skk-prefix)))))))
+      (skk-dcomp-multiple-show (skk-dcomp-multiple-get-candidates
+				(and (string= skk-dcomp-multiple-key
+					      (buffer-substring-no-properties
+					       skk-henkan-start-point (point)))
+				     (string= skk-dcomp-multiple-prefix skk-prefix)))))))
 
 ;; $BJ#?tI=<($N$?$a$K8!:w$7$F<-=q%P%C%U%!$N(B point $B$rF0$+$9$H!"(Bskk-comp $B$N(B
 ;; $BJd408uJd$,68$C$F$7$^$&$N$G0lC6J]B8$7$F$*$-:G8e$K85$KLa$9(B
@@ -277,7 +276,7 @@
 		       (not (skk-get-kana skk-current-rule-tree)))
 	       (skk-dcomp-save-point-in-jisyo-buffer
 		(while (and (< i skk-dcomp-multiple-rows)
-			    (setq cand (skk-comp-get-candidate (= i 0))))
+			    (setq cand (skk-comp-get-candidate (zerop i))))
 		  (unless (member cand candidates)
 		    (push cand candidates)
 		    (incf i)))))
@@ -322,7 +321,7 @@
 			      "??")))))))
 
 (defun skk-dcomp-multiple-show (candidates)
-  (skk-dcomp-multiple-hide)
+  (skk-delete-overlay skk-dcomp-multiple-overlays)
   (unless (skk-in-minibuffer-p)
     (let* ((margin 1)
 	   (beg-col (save-excursion
@@ -333,7 +332,7 @@
       (when candidates
 	(when (zerop beg-col)
 	  (setq margin 0))
-	(setq max-width (apply 'max (mapcar 'string-width candidates)))
+	(setq max-width (skk-max-string-width candidates))
 	(dolist (str candidates)
 	  (setq str (concat (make-string margin ? )
 			    str
@@ -372,7 +371,7 @@
 		   ;; after-string $B$KDI2C$9$k!#$?$@$7!"(BEOB $B$N>l9g$O(B
 		   ;; prefix $B$N(B overlay $B$H>WFM$9$k$?$a(B
 		   ;; `skk-prefix-overlay' $B$KDI2C$9$k(B
-		   (setq ol (if (= i 0)
+		   (setq ol (if (zerop i)
 				(cond ((or (not skk-echo)
 					   (string= "" skk-prefix)
 					   (< (overlay-end skk-prefix-overlay)
@@ -406,8 +405,7 @@
 				    (make-string (- col ol-end-col) ? ))))
 		(setq ol (make-overlay ol-beg (point)))
 		;; $B85%F%-%9%H$N(B face $B$r7Q>5$7$J$$$h$&$K(B1$B$D8e$m$K(B
-		;; overlay $B$r:n$C$F!"$=$N(B face $B$r(B 'default $B$K;XDj$7$F$*(B
-		;; $B$/(B
+		;; overlay $B$r:n$C$F!"$=$N(B face $B$r(B 'default $B$K;XDj$7$F$*$/(B
 		(setq base-ol (make-overlay (point) (1+ (point))))
 		(overlay-put base-ol 'face 'default)
 		(push base-ol skk-dcomp-multiple-overlays)
@@ -425,15 +423,9 @@
 			     (count-screen-lines (window-start) (point))))))
 	  (recenter (- (+ 2 skk-dcomp-multiple-rows))))))))
 
-(defun skk-dcomp-multiple-hide ()
-  (when skk-dcomp-multiple-overlays
-    (dolist (ol skk-dcomp-multiple-overlays)
-      (delete-overlay ol))
-    (setq skk-dcomp-multiple-overlays nil)))
-
 ;;;###autoload
 (defun skk-dcomp-before-kakutei ()
-  (skk-dcomp-multiple-hide)
+  (skk-delete-overlay skk-dcomp-multiple-overlays)
   (when (and (or skk-dcomp-activate
 		 skk-dcomp-multiple-activate)
 	     (eq skk-henkan-mode 'on)
@@ -456,7 +448,7 @@
 	     skk-mode
 	     (eq skk-henkan-mode 'on)
 	     (not skk-hint-inhibit-dcomp))
-    (skk-dcomp-multiple-hide)
+    (skk-delete-overlay skk-dcomp-multiple-overlays)
     (setq skk-dcomp-multiple-select-index -1)
     (when (skk-dcomp-marked-p)
       (skk-dcomp-face-off)
@@ -497,8 +489,7 @@
       (if (skk-get-prefix skk-current-rule-tree)
 	  (when (and (skk-dcomp-multiple-activate-p)
 		     (skk-dcomp-multiple-available-p))
-	    (skk-dcomp-multiple-show
-	     (skk-dcomp-multiple-get-candidates)))
+	    (skk-dcomp-multiple-show (skk-dcomp-multiple-get-candidates)))
 	(skk-dcomp-do-completion (point)))))))
 
 (defadvice skk-set-henkan-point-subr (around skk-dcomp-ad activate)
@@ -571,8 +562,7 @@
 		      (< skk-dcomp-multiple-select-index 0))
 		 (1- (length skk-comp-stack)))
 		(t (1- skk-dcomp-multiple-select-index))))
-    (skk-dcomp-multiple-show
-     (skk-dcomp-multiple-get-candidates t))))
+    (skk-dcomp-multiple-show (skk-dcomp-multiple-get-candidates t))))
 
 (defadvice skk-kakutei (around skk-dcomp-ad activate)
   (skk-dcomp-before-kakutei)
@@ -613,8 +603,7 @@
 		  (setq skk-dcomp-multiple-select-index
 			(skk-dcomp-multiple-increase-index
 			 skk-dcomp-multiple-select-index t))
-		  (skk-dcomp-multiple-show
-		   (skk-dcomp-multiple-get-candidates t))))))
+		  (skk-dcomp-multiple-show (skk-dcomp-multiple-get-candidates t))))))
 	(t
 	 ad-do-it
 	 (when (and (skk-dcomp-multiple-activate-p)
@@ -622,11 +611,10 @@
 	   (setq skk-dcomp-multiple-select-index
 		 (skk-dcomp-multiple-increase-index
 		  skk-dcomp-multiple-select-index))
-	   (skk-dcomp-multiple-show
-	    (skk-dcomp-multiple-get-candidates
-	     ;; skk-comp $B$N(B C-u TAB $B$r9MN8$9$k(B
-	     (not (and current-prefix-arg
-		       (listp current-prefix-arg)))))))))
+	   (skk-dcomp-multiple-show (skk-dcomp-multiple-get-candidates
+				     ;; skk-comp $B$N(B C-u TAB $B$r9MN8$9$k(B
+				     (not (and current-prefix-arg
+					       (listp current-prefix-arg)))))))))
 
 (defadvice skk-comp-do (before skk-dcomp-ad activate)
   (when (and skk-comp-use-prefix
@@ -642,8 +630,7 @@
     (skk-kana-cleanup 'force)
     (setq skk-dcomp-multiple-select-index
 	  (skk-dcomp-multiple-increase-index skk-dcomp-multiple-select-index))
-    (skk-dcomp-multiple-show
-     (skk-dcomp-multiple-get-candidates t))))
+    (skk-dcomp-multiple-show (skk-dcomp-multiple-get-candidates t))))
 
 (defadvice skk-comp-start-henkan (around skk-dcomp-ad activate)
    (cond ((and (eq skk-henkan-mode 'on)
