@@ -207,10 +207,12 @@
   ;;
   (when skk-show-japanese-menu
     (skk-emacs-menu-replace skk-emacs-modeline-menu)
-    (dolist (map (list skk-j-mode-map skk-latin-mode-map
-		       skk-jisx0208-latin-mode-map skk-abbrev-mode-map))
+    (dolist (map (list skk-j-mode-map
+		       skk-latin-mode-map
+		       skk-jisx0208-latin-mode-map
+		       skk-abbrev-mode-map))
       (skk-emacs-menu-replace (or (assq 'skk (assq 'menu-bar map))
-				(assq 'SKK (assq 'menu-bar map)))))))
+				  (assq 'SKK (assq 'menu-bar map)))))))
 
 (defun skk-emacs-modeline-menu ()
   (interactive)
@@ -305,7 +307,11 @@
   ;;
   (when window-system
     (let (face)
-      (dolist (mode '(hiragana katakana jisx0208-latin jisx0201 abbrev))
+      (dolist (mode '(hiragana
+		      katakana
+		      jisx0208-latin
+		      jisx0201
+		      abbrev))
 	(setq face (intern (format "skk-emacs-%s-face" mode)))
 	(unless (facep face)
 	  (make-face face)
@@ -336,6 +342,10 @@
 (defun skk-emacs-menu-replace (list)
   (let ((running-ntemacs (and (eq window-system 'w32)
 			      (not (fboundp 'Meadow-version))))
+	(workaround '("Hiragana"
+		      "Katakana"
+		      "Hankaku alphabet"
+		      "Zenkaku alphabet"))
 	cons)
     (while (and list (listp list))
       (cond
@@ -345,9 +355,7 @@
        ((and (stringp (car-safe list))
 	     (setq cons (assoc (car list) skk-emacs-menu-resource-ja)))
 	(setcar list (if (and running-ntemacs
-			      (member (car list) '("Hiragana" "Katakana"
-						   "Hankaku alphabet"
-						   "Zenkaku alphabet")))
+			      (member (car list) workaround))
 			 ;; NTEmacs $B$G(B Widget $BIU$-%a%K%e!<%"%$%F%`$N(B
 			 ;; $BF|K\8l$,$&$^$/I=<($G$-$J$$LdBj$X$NBP:v(B
 			 ;; (NTEmacs 22.1, 23.1)
@@ -356,9 +364,7 @@
        ((and (vectorp (car-safe list))
 	     (setq cons (assoc (aref (car list) 0) skk-emacs-menu-resource-ja)))
 	(aset (car list) 0 (if (and running-ntemacs
-				    (member (aref (car list) 0)
-					    '("Hiragana" "Katakana"
-					      "Hankaku alphabet" "Zenkaku alphabet")))
+				    (member (aref (car list) 0) workaround))
 			       ;; NTEmacs $B$G(B Widget $BIU$-%a%K%e!<%"%$%F%`$N(B
 			       ;; $BF|K\8l$,$&$^$/I=<($G$-$J$$LdBj$X$NBP:v(B
 			       ;; (NTEmacs 22.1, 23.1)
@@ -393,8 +399,8 @@
     ;; compute-motion returns (pos HPOS VPOS prevhpos contin)
     ;; we want:               (frame hpos . vpos)
     (cons (selected-frame)
-	  (cons (+ (car edges)       (car (cdr list)))
-		(+ (car (cdr edges)) (car (cdr (cdr list))))))))
+	  (cons (+ (car edges) (cadr list))
+		(+ (cadr edges) (car (cddr list)))))))
 
 (defun skk-tooltip-max-tooltip-size ()
   (if (boundp 'x-max-tooltip-size)
@@ -429,15 +435,16 @@
 	       (goto-char (point-max)))
 	      ;;
 	      (t
-	       (if (> (progn (end-of-line) (current-column)) max-columns)
-		   (progn
-		     (move-to-column max-columns)
-		     (backward-char)
-		     (if (member (char-to-string (following-char))
-				 skk-auto-start-henkan-keyword-list)
-			 (forward-char))
-		     (insert "\n" indent)
-		     (forward-line -1)))
+	       (when (> (progn (end-of-line)
+			       (current-column))
+			max-columns)
+		 (move-to-column max-columns)
+		 (backward-char)
+		 (if (member (char-to-string (following-char))
+			     skk-auto-start-henkan-keyword-list)
+		     (forward-char))
+		 (insert "\n" indent)
+		 (forward-line -1))
 	       (end-of-line)
 	       (setq current-column (current-column))
 	       (when (> current-column columns)
@@ -451,6 +458,9 @@
     (cons text (cons columns lines))))
 
 (defun skk-tooltip-show-at-point (text &optional situation)
+  "TEXT $B$r(B tooltip $B$GI=<($9$k!#(B
+$B%*%W%7%g%J%k0z?t(B SITUATION $B$,%7%s%\%k(B annotation $B$G$"$l$P!"(B
+$B%7%s%\%k(B listing $B$G$"$l$P!"(B"
   (require 'tooltip)
   ;; Emacs 21 $B$G$O!"%^%&%9%]%$%s%?Hs0MB8$N0LCV7hDj$,$G$-$J$$(B ($B$H;W$o$l$k(B)
   (when (eq emacs-major-version 21)
@@ -638,6 +648,9 @@
       (skk-unread-event event)))))
 
 (defun skk-tooltip-show-1 (text skk-params)
+  "TEXT $B$r(B tooltip $B$GI=<($9$k!#(B
+SKK-PARAMS $B$O(B `skk-tooltip-parameters' $BKt$O(B `tooltip-frame-parameters' $B$N$$$:$l$+!#(B
+TEXT $B$K$O(B `skk-tooltip-face' $B$,E,MQ$5$l$k!#(B"
   (condition-case error
       (let ((params (or skk-params tooltip-frame-parameters))
 	    fg bg)
