@@ -36,15 +36,18 @@
 (defun skk-add-background-color (string color)
   "STRING $B$N$J$+$GGX7J?';XDj$,$J$$J8;z$K$@$1(B COLOR $B$NGX7J?'$r$D$1$k!#(B"
   (when (eval-when-compile skk-running-gnu-emacs)
-    (when (and string color)
+    (when (and string
+	       color
+	       (color-defined-p color))
       (let ((start 0)
 	    (end 1)
+	    (len (length string))
 	    orig-face)
-	(while (< start (length string))
+	(while (< start len)
 	  (setq orig-face (get-text-property start 'face string))
-	  (while (and (< end (length string))
+	  (while (and (< end len)
 		      (eq orig-face (get-text-property end 'face string)))
-	    (setq end (1+ end)))
+	    (incf end))
 	  (cond
 	   ((not orig-face)
 	    (put-text-property start end 'face
@@ -85,15 +88,9 @@
 		end (1+ start)))))
     string))
 
-;;;###autoload
-(defun skk-inline-hide-1 ()
-  (dolist (ol skk-inline-overlays)
-    (delete-overlay ol))
-  (setq skk-inline-overlays nil))
-
 ;;;###autoload
 (defun skk-inline-show (str face &optional vertical-str text-max-height)
-  (skk-inline-hide)
+  (skk-delete-overlay skk-inline-overlays)
   (if (and (eq 'vertical skk-show-inline)
 	   ;; window $B$,8uJd72$rI=<($G$-$k9b$5$,$"$k$+%A%'%C%/(B
 	   (stringp vertical-str)
@@ -123,7 +120,7 @@
 	   ;; $B>l9g$"$j(B ?
 	   (beg-col (max 0 (- (skk-screen-column) margin)))
 	   (candidates (split-string string "\n"))
-	   (max-width (apply 'max (mapcar 'string-width candidates)))
+	   (max-width (skk-max-string-width candidates))
 	   (i 0)
 	   bottom col ol invisible)
       (dolist (str candidates)
@@ -135,8 +132,8 @@
 	(when face
 	  (setq str (propertize str 'face face)))
 	(when skk-inline-show-background-color
-	  (setq str (skk-add-background-color
-		     str skk-inline-show-background-color)))
+	  (setq str (skk-add-background-color str
+					      skk-inline-show-background-color)))
 	(save-excursion
 	  (scroll-left (max 0
 			    (- (+ beg-col margin max-width margin 1)
