@@ -5,9 +5,9 @@
 
 ;; Author: Enami Tsugutomo <enami@ba2.so-net.or.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-isearch.el,v 1.67 2010/11/17 21:15:18 skk-cvs Exp $
+;; Version: $Id: skk-isearch.el,v 1.70 2011/06/03 23:35:25 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/11/17 21:15:18 $
+;; Last Modified: $Date: 2011/06/03 23:35:25 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -430,7 +430,7 @@ Optional argument PREFIX is appended if given."
 	    ;; listify this-command-keys.  this works only if it is
 	    ;; string.
 	    (setq unread-command-events
-		  (append (if (= (length (this-command-keys)) 0)
+		  (append (if (zerop (length (this-command-keys)))
 			      (list last-command-event)
 			    (this-command-keys))
 			  nil))
@@ -606,7 +606,7 @@ If the current mode is different from previous, remove it first."
 
 (defun skk-isearch-exit (&rest args)
   (interactive "P")
-  (skk-isearch-kakutei (function isearch-exit)))
+  (skk-isearch-kakutei #'isearch-exit))
 
 (defun skk-isearch-newline (&rest args)
   (interactive "P")
@@ -624,7 +624,7 @@ If the current mode is different from previous, remove it first."
 	  (skk-isearch-mode-message))))
     (isearch-message))
    ((event-to-character last-command-event)
-    (skk-isearch-kakutei (function isearch-printing-char)))
+    (skk-isearch-kakutei #'isearch-printing-char))
    (t
     (skk-isearch-mode-message)
     (isearch-message))))
@@ -779,31 +779,31 @@ If the current mode is different from previous, remove it first."
 ;;; This advice will be enabled before skk-isearch is loaded.
 ;;;###autoload
 (defconst skk-isearch-really-early-advice
-  #'(lambda ()
-      (defadvice isearch-message-prefix (around skk-isearch-ad activate)
-	(let ((current-input-method
-	       (unless (and (boundp 'skk-isearch-switch)
-			    skk-isearch-switch)
-		 current-input-method)))
-	  ad-do-it))
-      (defadvice isearch-toggle-input-method (around skk-isearch-ad activate)
-	;; Needed for calling skk-isearch via isearch-x.
-	(cond ((string-match "^japanese-skk"
-			     (format "%s" default-input-method))
+  (lambda ()
+    (defadvice isearch-message-prefix (around skk-isearch-ad activate)
+      (let ((current-input-method
+	     (unless (and (boundp 'skk-isearch-switch)
+			  skk-isearch-switch)
+	       current-input-method)))
+	ad-do-it))
+    (defadvice isearch-toggle-input-method (around skk-isearch-ad activate)
+      ;; Needed for calling skk-isearch via isearch-x.
+      (cond ((string-match "^japanese-skk"
+			   (format "%s" default-input-method))
+	     (let ((skk-isearch-initial-mode-when-skk-mode-disabled
+		    'latin))
+	       (skk-isearch-mode-setup)
+	       (skk-isearch-skk-mode)))
+	    ((null default-input-method)
+	     ad-do-it
+	     (when (string-match "^japanese-skk"
+				 (format "%s" default-input-method))
 	       (let ((skk-isearch-initial-mode-when-skk-mode-disabled
 		      'latin))
-		 (skk-isearch-mode-setup)
-		 (skk-isearch-skk-mode)))
-	      ((null default-input-method)
-	       ad-do-it
-	       (when (string-match "^japanese-skk"
-				   (format "%s" default-input-method))
-		 (let ((skk-isearch-initial-mode-when-skk-mode-disabled
-			'latin))
-		   (skk-isearch-mode-setup))
-		 (inactivate-input-method)))
-	      (t
-	       ad-do-it)))))
+		 (skk-isearch-mode-setup))
+	       (inactivate-input-method)))
+	    (t
+	     ad-do-it)))))
 
 ;;;###autoload
 (unless (featurep 'xemacs)
