@@ -4,10 +4,10 @@
 
 ;; Author: Tsukamoto Tetsuo <czkmt@remus.dti.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-jisx0201.el,v 1.58 2010/09/10 15:47:02 skk-cvs Exp $
+;; Version: $Id: skk-jisx0201.el,v 1.60 2011/06/28 11:55:06 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Oct. 30, 1999.
-;; Last Modified: $Date: 2010/09/10 15:47:02 $
+;; Last Modified: $Date: 2011/06/28 11:55:06 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -153,28 +153,28 @@
   "*SKK JISX0201 $B%b!<%I$N%Y!<%9$N%k!<%k!#(B")
 
 (defvar skk-jisx0201-roman-rule-list
-  '(("!" nil "(J!(B") ("\"" nil "\(J"(B") ("#" nil "(J#(B") ("$" nil "(J$(B") ("%" nil "(J%(B")
-    ("&" nil "(J&(B") ("'" nil "(J'(B") ("\(" nil "(J((B") ("\)" nil "(J)(B") ("*" nil "(J*(B")
-    ("+" nil "(J+(B") ("," nil "(J,(B") ("-" nil "(J-(B") ("." nil "(J.(B") ("/" nil "(J/(B")
-    ("0" nil "(J0(B") ("1" nil "(J1(B") ("2" nil "(J2(B") ("3" nil "(J3(B") ("4" nil "(J4(B")
-    ("5" nil "(J5(B") ("6" nil "(J6(B") ("7" nil "(J7(B") ("8" nil "(J8(B") ("9" nil "(J9(B")
-    (":" nil "(J:(B") (";" nil "(J;(B") ("<" nil "(J<(B") ("=" nil "(J=(B") (">" nil "(J>(B")
-    ("?" nil "(J?(B") ("@" nil "(J@(B")
-    ("A" nil "(JA(B") ("B" nil "(JB(B") ("C" nil "(JC(B") ("D" nil "(JD(B") ("E" nil "(JE(B")
-    ("F" nil "(JF(B") ("G" nil "(JG(B") ("H" nil "(JH(B") ("I" nil "(JI(B") ("J" nil "(JJ(B")
-    ("K" nil "(JK(B") ("L" nil "(JL(B") ("M" nil "(JM(B") ("N" nil "(JN(B") ("O" nil "(JO(B")
-    ("P" nil "(JP(B") ("Q" nil "(JQ(B") ("R" nil "(JR(B") ("S" nil "(JS(B") ("T" nil "(JT(B")
-    ("U" nil "(JU(B") ("V" nil "(JV(B") ("W" nil "(JW(B") ("X" nil "(JX(B") ("Y" nil "(JY(B")
-    ("Z" nil "(JZ(B")
-    ("[" nil "(J[(B") ("\\" nil "\(J\(B") ("]" nil "(J](B") ("^" nil "(J^(B") ("_" nil "(J_(B")
-    ("`" nil "(J`(B")
-    ("a" nil "(Ja(B") ("b" nil "(Jb(B") ("c" nil "(Jc(B") ("d" nil "(Jd(B") ("e" nil "(Je(B")
-    ("f" nil "(Jf(B") ("g" nil "(Jg(B") ("h" nil "(Jh(B") ("i" nil "(Ji(B") ("j" nil "(Jj(B")
-    ("k" nil "(Jk(B") ("l" nil "(Jl(B") ("m" nil "(Jm(B") ("n" nil "(Jn(B") ("o" nil "(Jo(B")
-    ("p" nil "(Jp(B") ("q" nil "(Jq(B") ("r" nil "(Jr(B") ("s" nil "(Js(B") ("t" nil "(Jt(B")
-    ("u" nil "(Ju(B") ("v" nil "(Jv(B") ("w" nil "(Jw(B") ("x" nil "(Jx(B") ("y" nil "(Jy(B")
-    ("z" nil "(Jz(B")
-    ("{" nil "(J{(B") ("|" nil "(J|(B") ("}" nil "(J}(B") ("~" nil "(J~(B"))
+  '(("!" nil "!") ("\"" nil "\"") ("#" nil "#") ("$" nil "$") ("%" nil "%")
+    ("&" nil "&") ("'" nil "'") ("\(" nil "(") ("\)" nil ")") ("*" nil "*")
+    ("+" nil "+") ("," nil ",") ("-" nil "-") ("." nil ".") ("/" nil "/")
+    ("0" nil "0") ("1" nil "1") ("2" nil "2") ("3" nil "3") ("4" nil "4")
+    ("5" nil "5") ("6" nil "6") ("7" nil "7") ("8" nil "8") ("9" nil "9")
+    (":" nil ":") (";" nil ";") ("<" nil "<") ("=" nil "=") (">" nil ">")
+    ("?" nil "?") ("@" nil "@")
+    ("A" nil "A") ("B" nil "B") ("C" nil "C") ("D" nil "D") ("E" nil "E")
+    ("F" nil "F") ("G" nil "G") ("H" nil "H") ("I" nil "I") ("J" nil "J")
+    ("K" nil "K") ("L" nil "L") ("M" nil "M") ("N" nil "N") ("O" nil "O")
+    ("P" nil "P") ("Q" nil "Q") ("R" nil "R") ("S" nil "S") ("T" nil "T")
+    ("U" nil "U") ("V" nil "V") ("W" nil "W") ("X" nil "X") ("Y" nil "Y")
+    ("Z" nil "Z")
+    ("[" nil "[") ("\\" nil "\(J\(B") ("]" nil "]") ("^" nil "^") ("_" nil "_")
+    ("`" nil "`")
+    ("a" nil "a") ("b" nil "b") ("c" nil "c") ("d" nil "d") ("e" nil "e")
+    ("f" nil "f") ("g" nil "g") ("h" nil "h") ("i" nil "i") ("j" nil "j")
+    ("k" nil "k") ("l" nil "l") ("m" nil "m") ("n" nil "n") ("o" nil "o")
+    ("p" nil "p") ("q" nil "q") ("r" nil "r") ("s" nil "s") ("t" nil "t")
+    ("u" nil "u") ("v" nil "v") ("w" nil "w") ("x" nil "x") ("y" nil "y")
+    ("z" nil "z")
+    ("{" nil "{") ("|" nil "|") ("}" nil "}") ("~" nil "(J~(B"))
   "*SKK JISX0201 $B%b!<%I$N(B Roman $B$N%k!<%k!#(B")
 
 (defvar skk-jisx0201-rule-list
@@ -242,10 +242,8 @@
      (skk-jisx0201-zenkaku-region skk-henkan-start-point
 				  skk-okurigana-start-point))
     ;;
-    (let* ((pt1 (point))
-	   pt2
-	   okuri
-	   sokuon)
+    (let ((pt1 (point))
+	  pt2 okuri sokuon)
       (setq okuri
 	    (skk-save-point
 	     (backward-char 1)
@@ -410,18 +408,18 @@
   (skk-search-and-replace
    start end
    "[$B$!(B-$B$s!#!"!&!<!+!,(B]+"
-   #'(lambda (matched)
-       (save-match-data
-	 (skk-jisx0201-hankaku matched)))))
+   (lambda (matched)
+     (save-match-data
+       (skk-jisx0201-hankaku matched)))))
 
 ;;;###autoload
 (defun skk-katakana-to-jisx0201-region (start end)
   (skk-search-and-replace
    start end
    "[$B%!(B-$B%t!#!"!&!<!+!,(B]+"
-   #'(lambda (matched)
-       (save-match-data
-	 (skk-jisx0201-hankaku matched)))))
+   (lambda (matched)
+     (save-match-data
+       (skk-jisx0201-hankaku matched)))))
 
 (provide 'skk-jisx0201)
 
