@@ -28,6 +28,12 @@
 
 ;;; Code:
 
+(eval-when-compile
+  (require 'skk-macs))
+
+(require 'skk-cus)
+(require 'skk-vars)
+
 (eval-when-compile
   (defvar font-lock-defaults))
 
@@ -93,18 +99,44 @@
 
 ;;;###autoload
 (defun skk-edit-private-jisyo (&optional coding-system)
+  "$B8D?M<-=q%U%!%$%k(B `skk-jisyo' $B$rJT=8$9$k!#(B
+$BG$0U$G$N8D?M<-=qJ]B8$N$"$H!"(B`skk-jisyo' $B$r3+$-!"(B`skk-jisyo-edit-mode' $B$KF~$k!#(B
+$B%m!<%+%k$K(B $B0J2<$N%-!<Dj5A$,DI2C$5$l$k!#(B
+
+key       binding
+---       -------
+C-c C-c   Save & Exit
+C-c C-k   Abort
+
+SKK $B;HMQCf$N>l9g$O(B SKK $B$K$h$k8D?M<-=q%P%C%U%!$N99?7$,6X;_$5$l$k!#(B
+
+$B%*%W%7%g%s0z?t(B CODING-SYSTEM $B$K$F8D?M<-=q$N%3!<%I7O$r;XDj2DG=!#(B
+
+$B$3$N5!G=$O=>Mh$N<jF0$G$N8D?M<-=qJT=8$h$jG[N8$5$l$F$$$k$,!"(BSKK $B<-=q$N9=J8$r(B
+$B%A%'%C%/$9$k$3$H$O$G$-$:!"<+8J@UG$$G$NJT=8$G$"$k$3$H$OJQ$o$j$J$$!#(B"
   (interactive "P")
-  (when coding-system
-    (setq coding-system (read-coding-system
-			 "$B8D?M<-=q$N%3!<%G%#%s%0%7%9%F%`$r;XDj(B: "
-			 (skk-find-coding-system skk-jisyo-code))))
-  (unless coding-system
-    (setq coding-system (skk-find-coding-system skk-jisyo-code)))
-  ;;
-  (when (skk-y-or-n-p "$B<-=q$r%;!<%V$7$^$9$+!)(B "
-		      "Save jisyo? ")
-    (skk-save-jisyo))
-  (message nil)
+  (let (answer)
+    (unless skk-jisyo-edit-user-accepts-editing
+      (setq answer (skk-yes-or-no-p "\
+$B8D?M<-=q$NJT=8$O<-=q$r2u$92DG=@-$,$"$j$^$9!#<+8J@UG$$G$N<B9T$KF10U$7$^$9$+!)(B"
+				    "\
+You must edit your private dictionary at your own risk.  Do you accept it?"))
+      (when answer
+	(skk-cus-set '((skk-jisyo-edit-user-accepts-editing . t))))))
+  (when skk-jisyo-edit-user-accepts-editing
+    (when coding-system
+      (setq coding-system (read-coding-system
+			   "$B8D?M<-=q$N%3!<%G%#%s%0%7%9%F%`$r;XDj(B: "
+			   (skk-find-coding-system skk-jisyo-code))))
+    (unless coding-system
+      (setq coding-system (skk-find-coding-system skk-jisyo-code)))
+    ;;
+    (when (skk-y-or-n-p "$B8D?M<-=q$rJ]B8$7$^$9$+!)(B "
+			"Save private jisyo? ")
+      (skk-save-jisyo))
+    (skk-edit-private-jisyo-1 coding-system)))
+
+(defun skk-edit-private-jisyo-1 (coding-system)
   (setq skk-jisyo-edit-original-window-configuration
 	(current-window-configuration))
   ;; SKK $B<-=q$NJ8;z%3!<%I$O8mH=Dj$,$"$j$&$k$?$a!"Cm0U$9$k(B
@@ -136,26 +168,28 @@
   (ad-activate 'skk-henkan-in-minibuff)
   (ad-activate 'skk-purge-from-jisyo)
   (local-set-key "\C-c\C-c"
-		 #'(lambda ()
-		     (interactive)
-		     (when (skk-y-or-n-p "$BJT=8$r=*N;$7$^$9$+!)(B "
-					 "Finish editing jisyo? ")
-		       (save-buffer)
-		       (kill-buffer (current-buffer))
-		       (skk-reread-private-jisyo t)
-		       (set-window-configuration
-			skk-jisyo-edit-original-window-configuration))
-		     (message nil)))
+		 (lambda ()
+		   (interactive)
+		   (when (skk-y-or-n-p "$BJT=8$r=*N;$7$^$9$+!)(B "
+				       "Finish editing jisyo? ")
+		     (save-buffer)
+		     (kill-buffer (current-buffer))
+		     (skk-reread-private-jisyo t)
+		     (set-window-configuration
+		      skk-jisyo-edit-original-window-configuration))
+		   (message nil)))
   (local-set-key "\C-c\C-k"
-		 #'(lambda ()
-		     (interactive)
-		     (when (skk-y-or-n-p "$BJT=8$rCf;_$7$^$9$+!)(B "
-					 "Abort editing jisyo? ")
-		       (set-buffer-modified-p nil)
-		       (kill-buffer (current-buffer))
-		       (set-window-configuration
-			skk-jisyo-edit-original-window-configuration))
-		     (message nil))))
+		 (lambda ()
+		   (interactive)
+		   (when (skk-y-or-n-p "$BJT=8$rCf;_$7$^$9$+!)(B "
+				       "Abort editing jisyo? ")
+		     (set-buffer-modified-p nil)
+		     (kill-buffer (current-buffer))
+		     (set-window-configuration
+		      skk-jisyo-edit-original-window-configuration))
+		   (message nil)))
+  (skk-message "$BJ]B8=*N;(B: C-c C-c, $BJT=8Cf;_(B: C-c C-k"
+	       "Save & Exit: C-c C-c, Abort: C-c C-k"))
 
 (defadvice skk-henkan-in-minibuff (before notify-no-effect disable)
   (ding)
