@@ -7,9 +7,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-kcode.el,v 1.76 2010/12/21 03:23:21 skk-cvs Exp $
+;; Version: $Id: skk-kcode.el,v 1.97 2011/06/28 11:55:06 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/12/21 03:23:21 $
+;; Last Modified: $Date: 2011/06/28 11:55:06 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -33,7 +33,8 @@
 ;;; Code:
 
 (eval-when-compile
-  (require 'font-lock)
+  ;;   (require 'font-lock)
+  (require 'cl)
   (require 'skk-macs)
   (require 'skk-vars)
   (defvar enable-recursive-minibuffers)
@@ -43,70 +44,115 @@
 
 ;;;###autoload
 (defun skk-input-by-code-or-menu (&optional arg)
+  "$BJQ?t(B `skk-kcode-method' $B$G;XDj$5$l$?5!G=$rMQ$$$FJ8;z$rA^F~$9$k!#(B"
+  ;; `skk-rom-kana-base-rule-list' $B$,;X$7$F$$$k$N$O$3$N4X?t!#(B
+  (interactive "*P")
+  (let (list)
+    (case skk-kcode-method
+      (char-list
+       (skk-list-chars arg))
+      (code-or-char-list
+       (and (setq list (skk-input-by-code arg))
+	    (skk-list-chars arg)))
+      (this-key
+       (insert (format "%s" (this-command-keys))))
+      (t
+       (and (setq list (skk-input-by-code arg))
+	    (insert (apply #'skk-input-by-code-or-menu-0 list))))))
+  (when (eq skk-henkan-mode 'active)
+    (skk-kakutei)))
+
+(defun skk-input-by-code (&optional arg)
   "7/8 bit JIS $B%3!<%I(B $B$b$7$/$O(B $B6hE@HV9f$KBP1~$9$kJ8;z$rA^F~$9$k!#(B"
   (interactive "*P")
   (when arg
-    (setq skk-kcode-charset (intern (completing-read "Character set: "
-						     '(("japanese-jisx0213-1")
-						       ("japanese-jisx0213-2")
-						       ("japanese-jisx0208"))
-						     nil t
-						     (symbol-name skk-kcode-charset)))))
-  (let* ((str (read-string (format "\
-7/8 bits JIS code (00nn) or KUTEN code (00-00) for `%s' (CR for Jump Menu): "
-				   skk-kcode-charset)))
-	 (list (split-string str "-"))
+    (setq skk-kcode-charset (intern (completing-read
+				     "Character set: "
+				     '(("japanese-jisx0213-1")
+				       ("japanese-jisx0213-2")
+				       ("japanese-jisx0208"))
+				     nil t
+				     (symbol-name skk-kcode-charset)))))
+  (let* ((enable-recursive-minibuffers t)
+	 (codestr (skk-kcode-read-code-string))
+	 (list (skk-kcode-parse-code-string codestr))
+	 (flag (nth 0 list))
+	 (n1 (nth 1 list))
+	 (n2 (nth 2 list))
+	 (char (nth 3 list)))
+    (cond
+     ((> n1 160)
+      (insert (skk-kcode-find-char-string flag n1 n2 char))
+      nil)
+     (t
+      (list n1 n2)))))
+
+(defun skk-kcode-read-code-string ()
+  (read-string (format (if skk-japanese-message-and-error
+			   "\
+`%s' $B$NJ8;z$r;XDj$7$^$9!#(B7/8 $B%S%C%H(B JIS $B%3!<%I(B (00nn), $B6hE@%3!<%I(B (00-00),\
+ UNICODE (U+00nn), $B$^$?$O(B [RET] ($BJ8;z0lMw(B): "
+			 "\
+To find a character in `%s', type 7/8 bits JIS code (00nn),\
+ KUTEN code (00-00), UNICODE (U+00nn), or [RET] for List: ")
+		       skk-kcode-charset)))
+
+(defun skk-kcode-parse-code-string (str)
+  (let* ((list (split-string str "-"))
 	 (len (length list))
-	 (enable-recursive-minibuffers t)
-	 n1 n2 flag)
-    (cond ((eq len 2)			; $B%O%$%U%s(B `-' $B$G6h@Z$i$l$?!V6h(B-$BE@!W(B
-	   (setq n1 (+ (string-to-number (nth 0 list))
-		       32 128)
-		 n2 (+ (string-to-number (nth 1 list))
-		       32 128)))
-	  ((eq len 3)			; $B%O%$%U%s(B `-' $B$G6h@Z$i$l$?!VLL(B-$B6h(B-$BE@!W(B
-	   (setq flag (if (equal "2" (nth 0 list))
-			  'x0213-2
-			'x0213-1)
-		 n1 (+ (string-to-number (nth 1 list))
-		       32 128)
-		 n2 (+ (string-to-number (nth 2 list))
-		       32 128)))
-	  ((string-match "^[uU]\\+\\(.*\\)$" str) ; `U+' $B$G;O$^$l$P%f%K%3!<%I(B
-	   (setq flag 'unicode
-		 n1 161
-		 n2 0
-		 str (string-to-number (match-string-no-properties 1 str) 16)))
-	  (t				; $B>e5-0J30$O(B JIS $B%3!<%I$H$_$J$9(B
-	   (setq n1 (if (string= str "")
-			128
-		      (+ (* 16 (skk-char-to-hex (aref str 0) 'jis))
-			 (skk-char-to-hex (aref str 1))))
-		 n2 (if (string= str "")
-			128
-		      (+ (* 16 (skk-char-to-hex (aref str 2) 'jis))
-			 (skk-char-to-hex (aref str 3)))))))
+	 n1 n2 flag char)
+    (cond
+     ((eq len 2)
+      ;; $B%O%$%U%s(B `-' $B$G6h@Z$i$l$?!V6h(B-$BE@!W(B
+      (setq n1 (+ (string-to-number (nth 0 list))
+		  32 128)
+	    n2 (+ (string-to-number (nth 1 list))
+		  32 128)))
+     ((eq len 3)
+      ;; $B%O%$%U%s(B `-' $B$G6h@Z$i$l$?!VLL(B-$B6h(B-$BE@!W(B
+      (setq flag (if (equal "2" (nth 0 list))
+		     'x0213-2
+		   'x0213-1)
+	    n1 (+ (string-to-number (nth 1 list))
+		  32 128)
+	    n2 (+ (string-to-number (nth 2 list))
+		  32 128)))
+     ((string-match "^[uU]\\+\\(.*\\)$" str)
+      ;; `U+' $B$G;O$^$l$P%f%K%3!<%I(B
+      (setq flag 'unicode
+	    n1 161
+	    n2 0
+	    char (string-to-number (match-string-no-properties 1 str) 16)))
+     (t
+      ;; $B>e5-0J30$O(B JIS $B%3!<%I$H$_$J$9(B
+      (setq n1 (if (string= str "")
+		   128
+		 (+ (* 16 (skk-char-to-hex (aref str 0) 'jis))
+		    (skk-char-to-hex (aref str 1))))
+	    n2 (if (string= str "")
+		   128
+		 (+ (* 16 (skk-char-to-hex (aref str 2) 'jis))
+		    (skk-char-to-hex (aref str 3)))))))
     ;;
     (when (or (> n1 256)
 	      (> n2 256))
       (skk-error "$BL58z$J%3!<%I$G$9(B"
 		 "Invalid code"))
-    (insert (if (> n1 160)
-		(cond ((eq flag 'x0213-1)
-		       (char-to-string (skk-make-char 'japanese-jisx0213-1 n1 n2)))
-		      ((eq flag 'x0213-2)
-		       (char-to-string (skk-make-char 'japanese-jisx0213-2 n1 n2)))
-		      ((eq flag 'unicode)
-		       (char-to-string
-			(if (eval-when-compile (fboundp
-						'ucs-representation-decoding-backend))
-			    (ucs-representation-decoding-backend 'ucs str nil)
-			  str)))
-		      (t
-		       (skk-make-string n1 n2)))
-	      (skk-input-by-code-or-menu-0 n1 n2)))
-    (when (eq skk-henkan-mode 'active)
-      (skk-kakutei))))
+    (list flag n1 n2 char)))
+
+(defun skk-kcode-find-char-string (flag n1 n2 char)
+  (case flag
+    (x0213-1
+     (char-to-string (skk-make-char 'japanese-jisx0213-1 n1 n2)))
+    (x0213-2
+     (char-to-string (skk-make-char 'japanese-jisx0213-2 n1 n2)))
+    (unicode
+     (char-to-string
+      (if (fboundp 'ucs-representation-decoding-backend)
+	  (funcall #'ucs-representation-decoding-backend 'ucs char nil)
+	char)))
+    (t
+     (skk-make-string n1 n2))))
 
 (defun skk-char-to-hex (char &optional jischar)
   "CHAR $B$r(B 16 $B?J?t$H$_$J$7$F!"BP1~$9$k?tCM$r(B 10 $B?J?t$GJV$9!#(B"
@@ -128,7 +174,7 @@
 	       char))))
 
 (defun skk-make-string (n1 n2)
-  "skk-kcode-charset $B$,<($9J8;z=89g$K=>$C$F(B n1 n2 $B$KBP1~$9$k(B STRING $B$rJV$9(B"
+  "`skk-kcode-charset' $B$,<($9J8;z=89g$K=>$C$F(B n1 n2 $B$KBP1~$9$k(B STRING $B$rJV$9(B"
   (char-to-string (skk-make-char skk-kcode-charset n1 n2)))
 
 ;; tiny function, but called once in skk-kcode.el.  So not make it inline.
@@ -166,8 +212,8 @@
     (skk-input-by-code-or-menu-1 n1 n2)))
 
 (defun skk-input-by-code-or-menu-jump (n)
-  (let ((menu-keys1 (mapcar #'(lambda (char) ; $BI=<(MQ$N%-!<%j%9%H(B
-				(skk-char-to-unibyte-string (upcase char)))
+  (let ((menu-keys1 (mapcar (lambda (char) ; $BI=<(MQ$N%-!<%j%9%H(B
+			      (skk-char-to-unibyte-string (upcase char)))
 			    skk-input-by-code-menu-keys1))
 	kanji-char)
     (when (< n skk-code-n1-min)
@@ -207,7 +253,7 @@
 		   i (1+ i)))
 	   (if skk-show-tooltip
 	       (funcall skk-tooltip-function str)
-	     (message str)))
+	     (message "%s" str)))
 	 ;;
 	 (let* ((event (next-command-event))
 		(char (event-to-character event))
@@ -255,7 +301,7 @@
 `%s' EUC: %2x%2x (%3d, %3d), JIS: %2x%2x (%3d, %3d) [$B2?$+%-!<$r2!$7$F$/$@$5$$(B]"
 	      "\
 `%s' EUC: %2x%2x (%3d, %3d), JIS: %2x%2x (%3d, %3d) [Hit any key to continue]"
-	      (car (car chars))
+	      (caar chars)
 	      n-org skk-code-n1-min
 	      n-org skk-code-n1-min
 	      (- n-org 128) (- skk-code-n1-min 128)
@@ -272,13 +318,13 @@
 	     (setq n n-org)
 	     nil))))))
     (setq skk-input-by-code-or-menu-jump-default
-	  (car (cdr kanji-char)))
-    (skk-input-by-code-or-menu-1 (car (cdr kanji-char))
-				 (car (cdr (cdr kanji-char))))))
+	  (cadr kanji-char))
+    (skk-input-by-code-or-menu-1 (cadr kanji-char)
+				 (car (cddr kanji-char)))))
 
 (defun skk-input-by-code-or-menu-1 (n1 n2)
-  (let ((menu-keys2 (mapcar #'(lambda (char) ; $BI=<(MQ$N%-!<%j%9%H(B
-				(skk-char-to-unibyte-string (upcase char)))
+  (let ((menu-keys2 (mapcar (lambda (char) ; $BI=<(MQ$N%-!<%j%9%H(B
+			      (skk-char-to-unibyte-string (upcase char)))
 			    skk-input-by-code-menu-keys2))
 	kanji-char)
     (while (not kanji-char)
@@ -310,7 +356,7 @@
 		   i (1+ i)))
 	   (if skk-show-tooltip
 	       (funcall skk-tooltip-function str)
-	     (message str)))
+	     (message "%s" str)))
 	 (let* ((event (next-command-event))
 		(char (event-to-character event))
 		(key (skk-event-key event))
@@ -387,6 +433,7 @@
 (defun skk-display-code-for-char-at-point (&optional arg)
   "$B%]%$%s%H$K$"$kJ8;z$N6hE@HV9f!"(BJIS $B%3!<%I!"(BEUC $B%3!<%I5Z$S%7%U%H(B JIS $B%3!<%I(B\
  $B$rI=<($9$k!#(B"
+  (interactive)
   (if (eobp)
       (and (skk-message "$B%+!<%=%k$,%P%C%U%!$N=*C<$K$"$j$^$9(B"
 			"Cursor is at the end of the buffer")
@@ -395,13 +442,9 @@
     t))
 
 (defun skk-display-code (char)
-  (require 'font-lock)
-  (let* ((charset (if (eval-when-compile (and skk-running-gnu-emacs
-					      (>= emacs-major-version 23)))
-		      ;; GNU Emacs 23.1 or later
-		      (char-charset char skk-charset-list)
-		    (char-charset char)))
-	 mesg)
+;;   (require 'font-lock)
+  (let ((charset (skk-char-charset char skk-charset-list))
+	mesg)
     (cond
      ((memq charset '(japanese-jisx0213-1
 		      japanese-jisx0213-2
@@ -455,8 +498,7 @@
 		      (format "#x%2x%2x" char1-s char2-s)
 
 		      unicode
-		      (if (zerop (nth 2 char-data))
-			  ""
+		      (unless (zerop (nth 2 char-data))
 			(concat ", "
 				(propertize
 				 (format "$BAm(B%d$B2h!J(B%s$BIt(B %d$B2h!K(B"
@@ -464,11 +506,13 @@
 					 (aref skk-tankan-radical-vector
 					       (nth 0 char-data))
 					 (nth 1 char-data))
-				 'face 'font-lock-string-face)))
+				 'face 'skk-display-code-tankan-radical-face)))
 		      (if anno
 			  (concat ", "
-				  (propertize anno
-					      'face 'font-lock-string-face)))
+				  (propertize
+				   anno
+				   'face
+				   'skk-display-code-tankan-annotation-face)))
 			   ))))
      ;;
      ((memq charset '(ascii latin-jisx0201))
@@ -486,10 +530,9 @@
     (if (and window-system
 	     skk-show-tooltip
 	     (not (eq (symbol-function 'skk-tooltip-show-at-point) 'ignore)))
-	(funcall skk-tooltip-function (mapconcat #'(lambda (x) x)
-						 (split-string mesg ", ")
-						 "\n\t"))
-      (message mesg))))
+	(funcall skk-tooltip-function
+		 (replace-regexp-in-string ", " "\n\t" mesg))
+      (message "%s" mesg))))
 
 (defun skk-jis2sjis (char1 char2)
   (let* ((ch2 (if (eq (* (/ char1 2) 2) char1)
@@ -509,6 +552,12 @@
 	 (c1 (if (> ch2 127) (+ ch1 1) ch1)))
     (list c1 c2)))
 
+;; 2$BLL(B
+;; XEmacs $B$G$N%(%i!<2sHr$N$?$a$K$3$N4X?t$r0l;~(B skk-emacs.el $B$KB`Hr$9$k!#(B
+;; (autoload 'skk-jis2sjis2 "skk-emacs")
+(when (eval-when-compile (featurep 'xemacs))
+  (defalias 'skk-jis2sjis2 'ignore))
+
 ;;;; skk-list-chars
 ;; TODO
 ;;   o mode-line $B$K8=:_(B charset $B$rI=<($7$?$$(B
@@ -533,14 +582,14 @@
 	i ch)
     (insert "\n"
 	    (propertize
-	     (format "%02d-#x--- 0-- 1-- 2-- 3-- 4-- 5-- 6-- 7-- 8-- 9-- A-- B-- C-- D-- E-- F" (- high 32)) 'face 'font-lock-comment-face))
+	     (format "%02d-#x--- 0-- 1-- 2-- 3-- 4-- 5-- 6-- 7-- 8-- 9-- A-- B-- C-- D-- E-- F" (- high 32)) 'face 'skk-list-chars-table-header-face))
     (setq i (* (/ min 16) 16))		; i $B$O(B $B2<0L%P%$%H(B
     (while (<= i max)			; 0x21 .. 0x7e
-      (when (= (% i 16) 0)
+      (when (zerop (% i 16))
 	(insert (propertize (format "\n %5X0" (/ (+ (* high 256)
 						   i)
 						16))
-			    'face 'font-lock-comment-face)))
+			    'face 'skk-list-chars-table-header-face)))
       (setq ch (if (< i min)
 		   32
 		 (or (make-char charset (/ (* high 256) 256) i)
@@ -553,7 +602,10 @@
 ;;;###autoload
 (defun skk-list-chars (arg)
   "Docstring."
-  (require 'font-lock)
+  (interactive "p")
+;;   (require 'font-lock)
+  (setq skk-list-chars-original-window-configuration
+	(current-window-configuration))
   (let ((buf (progn (and (get-buffer skk-list-chars-buffer-name)
 			 (kill-buffer skk-list-chars-buffer-name))
 		    (get-buffer-create skk-list-chars-buffer-name)))
@@ -572,29 +624,27 @@
     (setq buffer-read-only nil)
     (erase-buffer)
     (set-buffer-multibyte t)
-    (insert (propertize (format "variable skk-kcode-charset's value is `%s'.\n"
-				skk-kcode-charset)
-			'face font-lock-doc-face))
-
-    (let ((high 33))			; ?\x21
-      (while (<= high 126)		; ?\x7e
-	(skk-list-chars-sub high skk-kcode-charset)
-	(setq high (1+ high))))
+    (insert (format "variable skk-kcode-charset's value is `%s'.\n"
+		    skk-kcode-charset))
+    (dotimes (high 94)			; from ?\x21 to ?\x7e
+      (skk-list-chars-sub (+ high 33) skk-kcode-charset))
     (pop-to-buffer buf)
     (search-backward ch)
     (setq skk-list-chars-point (point))
     (put-text-property skk-list-chars-point (progn (forward-char) (point))
-    		       'face 'font-lock-warning-face)
+		       'face 'skk-list-chars-face)
     (goto-char skk-list-chars-point)
     (set-buffer-modified-p nil)
     (setq buffer-read-only t)
-    (skk-list-chars-mode)))
+    (skk-list-chars-mode)
+    ;;
+    (when skk-list-chars-default-charstr
+      (skk-list-chars-move-to-charstr skk-list-chars-default-charstr))))
 
 (defun skk-list-chars-quit ()
   (interactive)
-  (if (one-window-p)
-      (switch-to-buffer skk-list-chars-destination-buffer) ;kill$B$5$l$F$$$k2DG=@-$"$j(B
-    (delete-window)))
+  (kill-buffer (current-buffer))
+  (set-window-configuration skk-list-chars-original-window-configuration))
 
 (defun skk-list-chars-display-code ()
   (interactive)
@@ -607,24 +657,45 @@
 (defun skk-list-chars-copy ()
   (interactive)
   (unless (eobp)
-    (message "`%s' copied." 
+    (message "`%s' copied."
 	     (kill-new (char-to-string (following-char))))))
 
 (defun skk-list-chars-next-line ()
   (interactive)
   (let ((col (current-column)))
+    (when (< col 8)
+      (setq col 8))
+    (unless (zerop (mod col 4))
+      (setq col (- col 2)))
     (forward-line)
-    (if (eq 'ascii (car (split-char (following-char))))
-	(next-completion 1))
-    (move-to-column col)))
+    (move-to-column col)
+    (when (eq 'ascii (car (split-char (following-char))))
+      (forward-line)
+      (move-to-column col)
+      (when (eq 'ascii (car (split-char (following-char))))
+	(forward-line)
+	(move-to-column col)))))
 
 (defun skk-list-chars-previous-line ()
   (interactive)
   (let ((col (current-column)))
-    (forward-line -1)
-    (if (eq 'ascii (car (split-char (following-char))))
-	(next-completion -1))
-    (move-to-column col)))
+    (when (< col 8)
+      (setq col 8))
+    (unless (zerop (mod col 4))
+      (setq col (- col 2)))
+    (if (< (count-lines (point-min) (point)) 5)
+	(progn
+	  (goto-char (point-min))
+	  (search-forward (char-to-string (make-char skk-kcode-charset 33 33)))
+	  (move-to-column col))
+      (forward-line -1)
+      (move-to-column col)
+      (when (eq 'ascii (car (split-char (following-char))))
+	(forward-line -1)
+	(move-to-column col)
+	(when (eq 'ascii (car (split-char (following-char))))
+	  (forward-line -1)
+	  (move-to-column col))))))
 
 (defun skk-list-chars-goto-point ()
   (interactive)
@@ -632,15 +703,16 @@
 
 (defun skk-list-chars-insert ()
   (interactive)
-  (if (eobp)
-      (forward-char -1)
-    (if (eq 'ascii (car (split-char (following-char))))
-	;; $B6h@Z$j9T$J$I$G(B RET $B$5$l$?>l9g(B
-	(next-completion 1)
-      (let ((c (following-char)))
-	(set-buffer skk-list-chars-destination-buffer) ; kill $B$5$l$F$$$k2DG=@-$"$j(B
-	(insert c))
-      )))
+  (when (buffer-live-p skk-list-chars-destination-buffer)
+    (if (eobp)
+	(forward-char -1)
+      (if (eq 'ascii (car (split-char (following-char))))
+	  ;; $B6h@Z$j9T$J$I$G(B RET $B$5$l$?>l9g(B
+	  (next-completion 1)
+	(let ((c (following-char)))
+	  (set-buffer skk-list-chars-destination-buffer)
+	  (insert c)
+	  (setq skk-list-chars-default-charstr (char-to-string c)))))))
 
 (defun skk-list-chars-other-charset ()
   (interactive)
@@ -656,51 +728,35 @@
 
 (defun skk-list-chars-code-input ()
   (interactive)
-  (let ((code (read-string
-	       (format "7/8 bits JIS code (00nn) or KUTEN code (00-00) or UNICODE (U+00nn) for `%s': " skk-kcode-charset))))
+  (skk-list-chars-jump 'insert))
+
+(defun skk-list-chars-jump (&optional insert)
+  (interactive)
+  (let ((code (skk-kcode-read-code-string))
+	str)
     (unless (string= code "")
-      (skk-list-chars-code-input-1 code))))
+      (setq str (skk-list-chars-find-char-string-for-code code))
+      (when str
+	(when insert
+	  (save-current-buffer
+	    (set-buffer skk-list-chars-destination-buffer)
+	    (insert str))
+	  (setq skk-list-chars-default-charstr str))
+	(skk-list-chars-move-to-charstr str)))))
 
-(defun skk-list-chars-code-input-1 (code)
-  (let ((str (cond
-	      ;; $B%O%$%U%s(B `-' $B$G6h@Z$i$l$?!V6h(B-$BE@!W(B
-	      ((string-match "^\\([0-9]*[0-9]\\)-\\([0-9]*[0-9]\\)$" code)
-	       (skk-make-string (+ (string-to-number (match-string 1 code))
-				   32 128)
-				(+ (string-to-number (match-string 2 code))
-				   32 128)))
-	      ;; `U+' $B$G;O$^$l$P%f%K%3!<%I(B
-	      ((string-match "^[uU]\\+\\(.*\\)$" code)
-	       (let ((char (string-to-number (match-string-no-properties 1 code) 16)))
-		 (char-to-string
-		  (cond ((eval-when-compile
-			   (fboundp 'ucs-representation-decoding-backend))
-			 (ucs-representation-decoding-backend 'ucs char nil))
-			((>= emacs-major-version 23)
-			 char)
-			(t
-			 32)))))
-	      ;; $B>e5-0J30$O(B JIS $B%3!<%I$H$_$J$9(B
-	      (t				
-	       (skk-make-string (+ (* 16 (skk-char-to-hex (aref code 0) 'jis))
-				   (skk-char-to-hex (aref code 1)))
-				(+ (* 16 (skk-char-to-hex (aref code 2) 'jis))
-				   (skk-char-to-hex (aref code 3))))))
-	     ))
-    (save-current-buffer
-      (set-buffer skk-list-chars-destination-buffer)
-      (insert str))
+(defun skk-list-chars-move-to-charstr (charstr)
+  (when (memq (skk-char-charset (string-to-char charstr) skk-charset-list)
+	      (list 'japanese-jisx0208 skk-kcode-charset))
     (goto-char (point-min))
-    (search-forward str nil t)
-    (forward-char -1))
-  (when (eq skk-henkan-mode 'active)
-    (skk-kakutei)))
+    (let ((case-fold-search nil))
+      (search-forward charstr nil t))
+    (forward-char -1)))
 
-;; 2$BLL(B
-;; XEmacs $B$G$N%(%i!<2sHr$N$?$a$K$3$N4X?t$r0l;~(B skk-emacs.el $B$KB`Hr$9$k!#(B
-;; (autoload 'skk-jis2sjis2 "skk-emacs")
-(when (eval-when-compile (featurep 'xemacs))
-  (defalias 'skk-jis2sjis2 'ignore))
+(defun skk-list-chars-find-char-string-for-code (code)
+  (let ((list (skk-kcode-parse-code-string code)))
+    (if (> (nth 1 list) 160)
+	(apply #'skk-kcode-find-char-string list)
+      nil)))
 
 (run-hooks 'skk-kcode-load-hook)
 
