@@ -4,9 +4,9 @@
 ;; Copyright (C) 1993-2000 Free Software Foundation, Inc.
 
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-macs.el,v 1.160 2010/12/16 11:16:08 skk-cvs Exp $
+;; Version: $Id: skk-macs.el,v 1.176 2011/06/24 23:58:03 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/12/16 11:16:08 $
+;; Last Modified: $Date: 2011/06/24 23:58:03 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -112,9 +112,9 @@ doesn't give arguments of `interactive'. See `interactive' for details."
 
 (defmacro skk-message (japanese english &rest arg)
   "$B%a%C%;!<%8$rI=<($9$k!#(B
-`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l$P(B
-ENGLISH $B$r%(%3!<%(%j%"$KI=<($9$k!#(BARG $B$O(B `message' $B4X?t$NBh#20z?t0J9_$N0z?t$H(B
-$B$7$FEO$5$l$k!#(B"
+`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G(B
+$B$"$l$P(B ENGLISH $B$r%(%3!<%(%j%"$KI=<($9$k!#(B
+ ARG $B$O(B `message' $B4X?t$NBh#20z?t0J9_$N0z?t$H$7$FEO$5$l$k!#(B"
   (append
    (if arg
        (list 'message (list 'if
@@ -129,9 +129,9 @@ ENGLISH $B$r%(%3!<%(%j%"$KI=<($9$k!#(BARG $B$O(B `message' $B4X?t$NBh#20z?t
 
 (defmacro skk-error (japanese english &rest arg)
   "$B%a%C%;!<%8$rI=<($7$F!"%(%i!<$rH/@8$5$;$k!#(B
-`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l$P(B
-ENGLISH $B$r%(%3!<%(%j%"$KI=<($7!"%(%i!<$rH/@8$5$;$k!#(B ARG $B$O(B `error' $B4X?t$NBh(B
-$B#20z?t0J9_$N0z?t$H$7$FEO$5$l$k!#(B"
+`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G(B
+$B$"$l$P(B ENGLISH $B$r%(%3!<%(%j%"$KI=<($7!"%(%i!<$rH/@8$5$;$k!#(B
+ ARG $B$O(B `error' $B4X?t$NBh#20z?t0J9_$N0z?t$H$7$FEO$5$l$k!#(B"
   (append
    (if arg
        (list 'error (list 'if
@@ -147,17 +147,17 @@ ENGLISH $B$r%(%3!<%(%j%"$KI=<($7!"%(%i!<$rH/@8$5$;$k!#(B ARG $B$O(B `error'
 (defmacro skk-yes-or-no-p (japanese english)
   "$B%f!<%6$K(B yes-or-no $B$r<ALd$7!"Ez$($,(B yes $B$@$C$?$i(B t $B$rJV$9!#(B
 `skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l(B
-$B$P(B ENGLISH $B$r%W%m%s%W%H$H$7$F(B `yes-or-no-p' $B$r<B9T$9$k!#(B
-`yes-or-no-p' $B$N0z?t$N%W%m%s%W%H$,J#;($KF~$l9~$s$G$$$k>l9g$O$3$N%^%/%m$r;H$&(B
-$B$h$j%*%j%8%J%k$N(B `yes-or-no-p' $B$r;HMQ$7$?J}$,%3!<%I$,J#;($K$J$i$J$$>l9g$,$"(B
-$B$k!#(B"
+$B$P(B ENGLISH $B$r(B PROMPT $B$H$7$F(B `yes-or-no-p' $B$r<B9T$9$k!#(B
+`yes-or-no-p' $B$N0z?t(B PROMPT $B$,J#;($KF~$l9~$s$G$$$k>l9g$O(B `skk-yes-or-no-p' $B$r(B
+$B;H$&$h$j$b%*%j%8%J%k$N(B `yes-or-no-p' $B$r;HMQ$7$?J}$,%3!<%I$,J#;($K$J$i$J$$>l9g(B
+$B$,$"$k!#(B"
  (list 'yes-or-no-p (list 'if 'skk-japanese-message-and-error
 				   japanese english)))
 
 (defmacro skk-y-or-n-p (japanese english)
   "$B%f!<%6$K(B \"y or n\" $B$r<ALd$7!"Ez$($,(B \"y\" $B$@$C$?$i(B t $B$rJV$9!#(B
 `skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l(B
-$B$P(B ENGLISH $B$r%W%m%s%W%H$H$7$F(B `y-or-n-p' $B$r<B9T$9$k!#(B"
+$B$P(B ENGLISH $B$r(B PROMPT $B$H$7$F(B `y-or-n-p' $B$r<B9T$9$k!#(B"
   (list 'y-or-n-p (list 'if 'skk-japanese-message-and-error
 				japanese english)))
 
@@ -222,6 +222,35 @@ MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
 	 (set-buffer buf)
 	 ,@body))))
 
+(defmacro skk-called-interactively-p (&optional kind)
+  (cond ((or (featurep 'xemacs)
+	     (= emacs-major-version 21))
+	 ;; XEmacs and GNU Emacs 21
+	 ;; `called-interactively-p' is not defined.
+	 '(interactive-p))
+
+	((or (>= emacs-major-version 24)
+	     (and (= emacs-major-version 23)
+		  (>= emacs-minor-version 2)))
+	 ;; GNU Emacs 23.2 or later
+	 ;; `called-interactively-p' takes one argument.
+	 `(called-interactively-p ,kind))
+
+	(t
+	 ;; GNU Emacs 22 and 23.1
+	 ;; `called-interactively-p' takes no argument and is equivalent
+	 ;; to (called-interactively-p 'any) in later Emacs versions.
+	 `(if (eq ,kind 'interactive)
+	      (interactive-p)
+	    (called-interactively-p)))))
+
+(defmacro skk-delete-overlay (list)
+  ;; skk-dcomp-multiple-hide $B$H(B skk-inline-hide $B$rE}9g$7$?!#(B
+  `(when ,list
+     (dolist (o ,list)
+       (delete-overlay o))
+     (setq ,list nil)))
+
 ;;; functions.
 ;; version dependent
 ;; Many functions are derived from emu (APEL).
@@ -263,7 +292,7 @@ If the event isn't a keypress, this returns nil."
 	(if mask
 	    (let ((base (get (car mask) 'ascii-character)))
 	      (if base
-		  (logior base (car (cdr mask))))))))
+		  (logior base (cadr mask)))))))
      ((integerp event)
       event))))
 
@@ -464,6 +493,15 @@ but the contents viewed as characters do change.
     ;; Emacs 22 $B0JA0!"$*$h$S(B XEmacs
     (split-char ch))))
 
+(defun skk-char-charset (ch &optional restriction)
+  (cond
+   ((eval-when-compile (and skk-running-gnu-emacs
+			    (>= emacs-major-version 23)))
+    ;; GNU Emacs 23.1 or later
+    (char-charset ch restriction))
+   (t
+    (char-charset ch))))
+
 ;; this one is called once in skk-kcode.el, too.
 (defun skk-charsetp (object)
   (cond
@@ -589,10 +627,6 @@ BUFFER defaults to the current buffer."
 	    force)
     (skk-cursor-set-1 color)))
 
-(defsubst skk-inline-hide ()
-  (when skk-inline-overlays
-    (skk-inline-hide-1)))
-
 (defun skk-cursor-off ()
   (unless (skk-color-cursor-display-p)
     (setq skk-use-color-cursor nil))
@@ -728,6 +762,9 @@ BUFFER defaults to the current buffer."
        (>= ?z char)))
 
 (defsubst skk-downcase (char)
+  "$BO"A[%j%9%H(B `skk-downcase-alist' $B$K3:Ev$"$l$P(B (assq)$B!"MWAG(B($B;R%j%9%H(B)$B$N(B cdr $B$rJV$9!#(B
+$B3:Ev$J$1$l$P(B $B4X?t(B `downcase'$B$N7k2L$rJV$9!#(B
+$B4X?t(B `skk-set-henkan-point' $B$+$i8F$P$l$F$$$k!#(B"
   (or (cdr (assq char skk-downcase-alist))
       (downcase char)))
 
@@ -840,6 +877,10 @@ BUFFER defaults to the current buffer."
 		     (- col (skk-screen-column))))
   (skk-screen-column))
 
+(defun skk-max-string-width (list)
+  "LIST $B$N3FMWAG$NCf$+$i!":GD9$N%3%i%`I}(B (string-width) $B$rJV$9!#(B"
+  (apply 'max (mapcar 'string-width list)))
+
 (defun skk-insert-prefix (&optional char)
   "`skk-echo' $B$,(B non-nil $B$G$"$l$P%+%l%s%H%P%C%U%!$K(B `skk-prefix' $B$rA^F~$9$k!#(B"
   (when skk-echo
@@ -876,7 +917,7 @@ BUFFER defaults to the current buffer."
     (string< str1 str2))))
 
 (defsubst skk-string<= (str1 str2)
-  "STR1 $B$H(B STR2 $B$H$rHf3S$7$F!"(Bstring< $B$+(B string= $B$G$"$l$P!"(Bt $B$rJV$9!#(B"
+  "STR1 $B$H(B STR2 $B$H$rHf3S$7$F!"(B`string<' $B$+(B `string=' $B$G$"$l$P!"(Bt $B$rJV$9!#(B"
   (or (skk-string< str1 str2)
       (string= str1 str2)))
 
@@ -998,27 +1039,25 @@ BUFFER defaults to the current buffer."
   (nth 1 (buffer-list)))
 
 (defun skk-quote-char-1 (word alist)
-  (mapconcat
-   #'(lambda (char)
-       (or (cdr (assq char alist))
-	   (char-to-string char)))
+  (mapconcat (lambda (char)
+	       (or (cdr (assq char alist))
+		   (char-to-string char)))
    ;; $BJ8;zNs$rBP1~$9$k(B char $B$N%j%9%H$KJ,2r$9$k!#(B
-   (append word nil) ""))
+	     (append word nil) ""))
 
 (defun skk-key-binding-member (key commands &optional map)
   "$BF~NO(B KEY $B$,H/F0$9$k%3%^%s%I$,!"(BCOMMANDS $B$K4^$^$l$l$P(B non-nil $B$rJV$9!#(B
 MAP $B$OF~NO$,=q$+$l$F$$$k%-!<%^%C%W$r;XDj$9$k$,!";XDj$5$l$J$1$l$P(B
 `skk-j-mode-map' $B$r;2>H$9$k!#(B
 $B$3$N4X?t$O!"F~NO(B KEY $B$,(B `lookup-key' $B$GC5$;$J$$7A<0$G$"$j$&$k>l9g$KMQ$$$k!#(B"
+  (unless map
+    (setq map skk-j-mode-map))
   (let (keys)
-    (unless map
-      (setq map skk-j-mode-map))
     (dolist (command commands)
       (setq keys (nconc keys
 			(where-is-internal command map))))
     (member (key-description key)
-	    (mapcar #'(lambda (k)
-			(key-description k))
+	    (mapcar #'key-description
 		    keys))))
 
 (defun skk-update-minor-mode-map-alist (mode map)
@@ -1052,6 +1091,14 @@ Return the modified ALIST."
   (and (boundp symbol)
        (set symbol (skk-del-alist key (symbol-value symbol)))))
 
+(defun skk-fit-window (&optional window)
+  "$B%+%l%s%H%&%#%s%I%&(B ($BKt$O(B WINDOW) $B$r!"$=$NI=<(FbMF$K1~$8$?9b$5$KD4@a$9$k!#(B"
+  (unless (eval-when-compile (and (featurep 'xemacs)
+				  (= emacs-major-version 21)
+				  (<= emacs-minor-version 4)))
+    ;; XEmacs 21.4 $B$K$O$J$$4X?t(B
+    (fit-window-to-buffer window)))
+
 (provide 'skk-macs)
 
 ;;; skk-macs.el ends here
