@@ -130,7 +130,7 @@
 		(setq cont nil))))
 	  (goto-char (point-min))
 	  (when skk-server-report-response
-	    (skk-message "$B<-=q%5!<%P!<$N1~Ez$r(B %d $B2sBT$A$^$7$?(B"
+	    (skk-message "$B<-=q%5!<%P$N1~Ez$r(B %d $B2sBT$A$^$7$?(B"
 			 "Waited for server response %d times"
 			 count))
 	  (when (eq (following-char) ?1) ;?1
@@ -140,9 +140,7 @@
 	    (setq ret
 		  (save-match-data
 		    (split-string (buffer-substring-no-properties
-				   (point) (progn
-					     (end-of-line)
-					     (1- (point))))
+				   (point) (1- (line-end-position)))
 				  sep)))
 	    (when (string= sep "/")
 	      ;; $B8+=P$7$K(B '/' $B$r4^$s$G$$$k;~!"%;%Q%l!<%?$N(B '/' $B$H:.F1$7!"(B
@@ -150,13 +148,13 @@
 	      (setq ret
 		    (delq nil
 			  (let ((len (length key)))
-			    (mapcar #'(lambda (midasi)
-					;; key $B$K40A40lCW$J(B midasi $B$r$I$&$9$k$+!#(B
-					(when (and (> (length midasi) len)
-						   (string-equal key
-								 (substring midasi
-									    0 len)))
-					  midasi))
+			    (mapcar (lambda (midasi)
+				      ;; key $B$K40A40lCW$J(B midasi $B$r$I$&$9$k$+!#(B
+				      (when (and (> (length midasi) len)
+						 (string-equal key
+							       (substring midasi
+									  0 len)))
+					midasi))
 				    ret)))))
 	    ret))))))
 
