@@ -1,4 +1,4 @@
-;;; skk-server.el --- $B<-=q%5!<%P!<$N$?$a$N%W%m%0%i%`(B -*- coding: iso-2022-jp -*-
+;;; skk-server.el --- $B<-=q%5!<%P$N$?$a$N%W%m%0%i%`(B -*- coding: iso-2022-jp -*-
 
 ;; Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996,
 ;;               1997, 1998, 1999, 2000, 2001
@@ -6,9 +6,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-server.el,v 1.48 2010/09/10 15:29:32 skk-cvs Exp $
+;; Version: $Id: skk-server.el,v 1.52 2011/05/03 10:40:36 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/09/10 15:29:32 $
+;; Last Modified: $Date: 2011/05/03 10:40:36 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -49,18 +49,18 @@ When PROCESS is nil, check `skkserv-process' instead."
 When called interactively, print version information."
   (interactive)
   (cond
-   ((interactive-p)
+   ((skk-called-interactively-p 'interactive)
     (message "%s" (skk-server-version)))
    ((not (or skk-server-host
 	     skk-servers-list))
     (skk-error "Lack of host information of SKK server"
-	       "$B<-=q%5!<%P!<$N%[%9%H>pJs$,$"$j$^$;$s(B"))
+	       "$B<-=q%5!<%P$N%[%9%H>pJs$,$"$j$^$;$s(B"))
    ((skk-server-live-p (skk-open-server))
     (let (v)
       (save-match-data
 	(with-current-buffer skkserv-working-buffer
 	  (erase-buffer)
-	  ;; $B<-=q%5!<%P!<$N%P!<%8%g%s$rF@$k!#(B
+	  ;; $B<-=q%5!<%P$N%P!<%8%g%s$rF@$k!#(B
 	  (process-send-string skkserv-process "2")
 	  (while (eq (buffer-size) 0)
 	    (accept-process-output))
@@ -82,7 +82,7 @@ When called interactively, print version information."
 
 ;;;###autoload
 (defun skk-search-server-1 (file limit)
-  "skk-search-server $B$N%5%V%k!<%A%s!#(B"
+  "`skk-search-server' $B$N%5%V%k!<%A%s!#(B"
   (let ((key
 	 (if skk-use-numeric-conversion
 	     (skk-num-compute-henkan-key skk-henkan-key)
@@ -101,7 +101,7 @@ When called interactively, print version information."
 	  (while (and cont (skk-server-live-p))
 	    (accept-process-output)
 	    ;; XXX workaround
-	    ;; dbskkd-cdb $B$d(B skksearch $B$J$I$N<-=q%5!<%P!<$r;H$C$FJQ49$9$k(B
+	    ;; dbskkd-cdb $B$d(B skksearch $B$J$I$N<-=q%5!<%P$r;H$C$FJQ49$9$k(B
 	    ;; $B:]$K!"(B2 $BIC$[$IBT$?$5$l$k$3$H$,$"$k!#$I$&$d$i1~EzBT$A$N%k!<%W(B
 	    ;; $B$,IiC4$K$J$C$F$$$k$h$&$G!"B?$$$H$-$K$O?tI4!A:GBg$G?t==K|2s$N(B
 	    ;; $B1~EzBT$A$K$J$k$3$H$,$"$k!#(Bskk-server-report-response $B$r(B t $B$K(B
@@ -121,7 +121,7 @@ When called interactively, print version information."
 		(setq cont nil))))
 	  (goto-char (point-min))
 	  (when skk-server-report-response
-	    (skk-message "$B<-=q%5!<%P!<$N1~Ez$r(B %d $B2sBT$A$^$7$?(B"
+	    (skk-message "$B<-=q%5!<%P$N1~Ez$r(B %d $B2sBT$A$^$7$?(B"
 			 "Waited for server response %d times"
 			 count))
 	  (when (eq (following-char) ?1) ;?1
@@ -144,7 +144,7 @@ When called interactively, print version information."
 	(skk-search-jisyo-file file limit))))))
 
 (defun skk-open-server ()
-  "$B<-=q%5!<%P!<$H@\B3$9$k!#%5!<%P!<%W%m%;%9$rJV$9!#(B"
+  "$B<-=q%5!<%P$H@\B3$9$k!#%5!<%P!<%W%m%;%9$rJV$9!#(B"
   (unless (skk-server-live-p)
     (setq skkserv-process (skk-open-server-1))
     (when (skk-server-live-p)
@@ -241,7 +241,7 @@ HOST $B$,(B nil $B$J$i$P(B `skk-server-host' $B$r;2>H$9$k!#(B
       ;; skkserv $B$N5/F0%H%i%$%"%k$r7+$jJV$9(B...?
       (while (> count 0)
 	(skk-message
-	 "%s $B$N<-=q%5!<%P!<$,5/F0$7$F$$$^$;$s!#5/F0$7$^$9(B%s"
+	 "%s $B$N<-=q%5!<%P$,5/F0$7$F$$$^$;$s!#5/F0$7$^$9(B%s"
 	 "SKK SERVER on %s is not active, I will activate it%s"
 	 host (make-string count ?.))
 	(if (or (string= host (system-name))
@@ -266,14 +266,14 @@ HOST $B$,(B nil $B$J$i$P(B `skk-server-host' $B$r;2>H$9$k!#(B
       ;;
       (cond
        ((skk-server-live-p process)
-	(skk-message "$B%[%9%H(B %s $B$N<-=q%5!<%P!<$,5/F0$7$^$7$?(B"
+	(skk-message "$B%[%9%H(B %s $B$N<-=q%5!<%P$,5/F0$7$^$7$?(B"
 		     "SKK SERVER on %s is active now"
 		     skk-server-host)
 	(sit-for 1)
 	;; process $B$rJV$jCM$H$9$k(B
 	process)
        (t
-	(skk-message "%s $B$N<-=q%5!<%P!<$r5/F0$9$k$3$H$,$G$-$^$;$s$G$7$?(B"
+	(skk-message "%s $B$N<-=q%5!<%P$r5/F0$9$k$3$H$,$G$-$^$;$s$G$7$?(B"
 		     "Could not activate SKK SERVER on %s"
 		     skk-server-host)
 	(sit-for 1)
@@ -303,7 +303,7 @@ non-nil $B$G$"$l$P!"2C$($k!#(B"
 
 ;;;###autoload
 (defun skk-disconnect-server ()
-  "$B<-=q%5!<%P!<$r@Z$jN%$9!#(B"
+  "$B<-=q%5!<%P$r@Z$jN%$9!#(B"
   (when (and skk-server-host
 	     (skk-server-live-p))
     ;; disconnect server
