@@ -7,9 +7,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-tut.el,v 1.79 2010/11/10 19:25:03 skk-cvs Exp $
+;; Version: $Id: skk-tut.el,v 1.85 2011/06/04 01:30:22 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/11/10 19:25:03 $
+;; Last Modified: $Date: 2011/06/04 01:30:22 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -104,10 +104,10 @@
     (skk-henkan-show-candidates-rows . 1)
     (skk-show-candidates-always-pop-to-buffer . nil)
     (skk-henkan-strict-okuri-precedence . nil)
-    (skk-previous-candidate-char
-     . (if (equal skk-tut-file skktut-nicola-tut-file)
-	   ?\C-p
-	?x))
+    (skk-previous-candidate-keys
+     . (if (skk-tut-nicola-p)
+	   '("\C-p")
+	 '("\C-p" "x")))
     (skk-hiragana-mode-string . " $B$+$J(B")
     (skk-init-file . "")
     (skk-input-by-code-menu-keys1 . '(?a ?s ?d ?f ?g ?h ?q ?w ?e ?r ?t ?y))
@@ -123,15 +123,14 @@
     (skk-kakutei-early . t)
     (skk-kakutei-key . "\C-j")
     (skk-kana-input-search-function
-     . (function
-	(lambda ()
-	  (save-match-data
-	    (when (and (string-match
-			"^h\\([bcdfghjklmnpqrstvwxz]\\)$"
-			skk-prefix)
-		       (member (char-to-string (preceding-char))
-			       '("$B$*(B" "$B%*(B")))
-	      (cons '("$B%*(B" . "$B$*(B") (match-string 1 skk-prefix)))))))
+     . (lambda ()
+	 (save-match-data
+	   (when (and (string-match
+		       "^h\\([bcdfghjklmnpqrstvwxz]\\)$"
+		       skk-prefix)
+		      (member (char-to-string (preceding-char))
+			      '("$B$*(B" "$B%*(B")))
+	     (cons '("$B%*(B" . "$B$*(B") (match-string 1 skk-prefix))))))
     (skk-katakana-mode-string . " $B%+%J(B")
     (skk-kcode-load-hook . nil)
     (skk-keep-record . nil)
@@ -286,10 +285,9 @@
     (skk-start-henkan-key . " ")
     (skk-try-completion-char . ?\011)
     (skk-update-jisyo-function . 'skktut-update-jisyo)
-    (skk-use-color-cursor
-     . (and window-system
-	    (fboundp 'x-display-color-p)
-	    (x-display-color-p)))
+    (skk-use-color-cursor . (and window-system
+				 (fboundp 'x-display-color-p)
+				 (x-display-color-p)))
     (skk-use-face . window-system)
     (skk-use-look . nil)
     (skk-use-numeric-conversion . t)
@@ -303,6 +301,10 @@
 			     (quote japanese-jisx0208)
 			   skk-kcode-charset))
     (skk-dcomp-activate . nil)
+    (skk-dcomp-multiple-activate . nil)
+    (skk-read-from-minibuffer-function . nil)
+    (skk-verbose . nil)
+    (debug-on-error . nil)
 
     ;; not user variables but to be localized.
     (skk-insert-new-word-function . nil)
@@ -310,10 +312,9 @@
     (skk-rule-tree
      .
      (if (and skk-use-kana-keyboard
-	     (memq skk-kanagaki-keyboard-type
-		   '(oasys
-		     nicola-jis nicola-us nicola-dvorak
-		     omelet-jis omelet-us omelet-dvorak))
+	     (memq skk-kanagaki-keyboard-type '(oasys
+						nicola-jis nicola-us nicola-dvorak
+						omelet-jis omelet-us omelet-dvorak))
 	     (eq skk-kanagaki-state 'kana)
 	     skktut-nicola-tut-file)
 	 skk-kanagaki-rule-tree
@@ -321,12 +322,9 @@
 			      skk-rom-kana-rule-list))))
   "skk.el $B$N%f!<%6!<JQ?t$N%j%9%H!#(B")
 
-(defvar skktut-nicola-tut-file
-  (when skk-tut-file
-    (expand-file-name "NICOLA-SKK.tut"
-		      (expand-file-name
-		       (file-name-directory skk-tut-file))))
-  "NICOLA-DDSKK $B$N$?$a$N%A%e!<%H%j%"%k%U%!%$%k!#(B")
+(defvar skktut-nicola-tut-file "NICOLA-SKK.tut"
+  "NICOLA-DDSKK $B$N$?$a$N%A%e!<%H%j%"%k%U%!%$%kL>!#(B
+$B%G%#%l%/%H%jL>$O4^$^$J$$!#(B")
 
 (defvar skktut-japanese-tut nil
   "Non-nil $B$G$"$l$P!"%A%e!<%H%j%"%k$,F|K\8l$G$"$k$3$H$r<($9!#(B")
@@ -446,19 +444,19 @@
 
 ;; hooks
 (add-hook 'kill-buffer-hook
-	  #'(lambda ()
-	      (when (and (interactive-p)
-			 (member (buffer-name (current-buffer))
-				 (list skktut-working-buffer
-				       skktut-question-buffer
-				       skktut-answer-buffer
-				       skktut-jisyo-buffer)))
-		(skk-tutorial-quit 'now))))
+	  (lambda ()
+	    (when (and (skk-called-interactively-p 'interactive)
+		       (member (buffer-name (current-buffer))
+			       (list skktut-working-buffer
+				     skktut-question-buffer
+				     skktut-answer-buffer
+				     skktut-jisyo-buffer)))
+	      (skk-tutorial-quit 'now))))
 
 (add-hook 'kill-emacs-hook
-	  #'(lambda ()
-	      (when (buffer-live-p (get-buffer skktut-jisyo-buffer))
-		(skk-tutorial-quit 'now))))
+	  (lambda ()
+	    (when (buffer-live-p (get-buffer skktut-jisyo-buffer))
+	      (skk-tutorial-quit 'now))))
 
 ;; interactive commands. prefix should be `skk-tutorial'.
 ;;;###autoload
@@ -485,28 +483,47 @@ You can select English version by \\[universal-argument] \\[skk-tutorial]."
 	     (eq skk-kanagaki-state 'kana)
 	     skktut-nicola-tut-file)
     (skk-nicola-setup-tutorial)
-    (setq skk-tut-file skktut-nicola-tut-file))
+    (setq skk-tut-file (expand-file-name skktut-nicola-tut-file
+					 (file-name-directory skk-tut-file))))
   ;;
-  (when query-language
-    (let* ((lang (completing-read "Language: "
-				  skk-tut-file-alist))
-	   (file (cdr (assoc lang skk-tut-file-alist))))
-      (unless (file-exists-p (expand-file-name file))
-	(error "No file found as %s" file))
-      (setq skk-tut-file file)
+  (let ((file skk-tut-file))
+    (when (and (null skk-tut-current-lang)
+	       skk-tut-lang)
+      (setq skk-tut-current-lang skk-tut-lang))
+    (when query-language
+      (setq skk-tut-current-lang (completing-read "Language: "
+						  skk-tut-file-suffix-alist))
       (message "Language for the tutorial is %s until you exit Emacs"
-	       lang)))
-  (let ((inhibit-quit t))
-    (skktut-pre-setup-tutorial)
-    (skktut-setup-jisyo-buffer)
-    (skktut-setup-working-buffer)
-    (skktut-setup-question-buffer)
-    (skktut-setup-answer-buffer)
-    (skktut-enable-advice)
-    (skktut-enable-tutmap)
-    (add-hook 'minibuffer-setup-hook 'skktut-localize-and-init-variables)
-    (skktut-make-windows))
-  (skktut-setup-delete-backward-char))
+	       skk-tut-current-lang))
+    (when skk-tut-current-lang
+      (setq file (skk-tut-find-tut-file file)))
+    (unless (file-exists-p (expand-file-name file))
+	(error "No file found as %s" file))
+    (let ((inhibit-quit t))
+      (skktut-pre-setup-tutorial)
+      (skktut-setup-jisyo-buffer)
+      (skktut-setup-working-buffer file)
+      (skktut-setup-question-buffer)
+      (skktut-setup-answer-buffer)
+      (skktut-enable-advice)
+      (skktut-enable-tutmap)
+      (add-hook 'minibuffer-setup-hook 'skktut-localize-and-init-variables)
+      (skktut-make-windows))
+    (skktut-setup-delete-backward-char)))
+
+(defun skk-tut-nicola-p ()
+  (equal skk-tut-file (expand-file-name skktut-nicola-tut-file
+					(file-name-directory skk-tut-file))))
+
+(defun skk-tut-find-tut-file (file)
+  (cond
+   ((skk-tut-nicola-p)
+    skk-tut-file)
+   (t
+    (when (string-match "SKK\\.tut\\.\\w" file)
+      (setq file (substring file 0 (- (match-end 0) 2))))
+    (concat file (cdr (assoc skk-tut-current-lang
+			     skk-tut-file-suffix-alist))))))
 
 (defun skk-tutorial-again (&optional now)
   "$B%f!<%6$NF10U$,$"$l$P(B SKK $B%A%e!<%H%j%"%k$r:G=i$+$i$d$jD>$9!#(B
@@ -636,11 +653,9 @@ You can select English version by \\[universal-argument] \\[skk-tutorial]."
     (skk-update-minor-mode-map-alist 'skk-abbrev-mode skktut-abbrev-mode-map)
     (skk-update-minor-mode-map-alist 'skk-j-mode skktut-j-mode-map)
     (skk-update-minor-mode-map-alist 'skk-jisx0208-mode skktut-jisx0208-latin-mode-map)
-    (define-key skktut-j-mode-map
-      (if (equal skk-tut-file skktut-nicola-tut-file)
-	  "\C-p"
-	"x")
-      'skk-previous-candidate)
+    (define-key skktut-j-mode-map "\C-p" 'skk-previous-candidate)
+    (unless (skk-tut-nicola-p)
+      (define-key skktut-j-mode-map "x" 'skk-previous-candidate))
     (define-key skktut-j-mode-map "\C-j" 'skk-insert)
     (define-key skktut-j-mode-map "\t" 'skk-insert)
     ;; for minor-mode-map-alist localized by Viper.
@@ -752,14 +767,14 @@ tutorial /$B%A%e!<%H%j%"%k(B/
 ")
     (skk-setup-jisyo-buffer)))
 
-(defun skktut-setup-working-buffer ()
+(defun skktut-setup-working-buffer (file)
   (save-match-data
     (let (sexp)
       (set-buffer (get-buffer-create skktut-working-buffer))
       (buffer-disable-undo (current-buffer))
       (skktut-localize-and-init-variables)
       (skktut-erase-buffer) ; fail safe.
-      (insert-file-contents skk-tut-file)
+      (insert-file-contents file)
       ;; Count how many questions there are.
       (setq skktut-question-numbers -1)
       (goto-char (point-min))
@@ -851,9 +866,8 @@ tutorial /$B%A%e!<%H%j%"%k(B/
       (search-backward "\n>>")
       (forward-char 1)
       (setq skktut-right-answer
-	    (buffer-substring-no-properties
-	     (+ 3 (point))
-	     (skk-save-point (end-of-line) (point))))
+	    (buffer-substring-no-properties (+ 3 (point))
+					    (line-end-position)))
       (goto-char (point-min)))
     ;; not to save point.
     (let ((cbuf (current-buffer))
@@ -938,9 +952,7 @@ tutorial /$B%A%e!<%H%j%"%k(B/
       (let (p)
 	(widen)
 	(search-forward "\n>> ")
-	(when (re-search-forward "$B!V(B.*$B!W(B"
-				 (skk-save-point (end-of-line) (point))
-				 t)
+	(when (re-search-forward "$B!V(B.*$B!W(B" (line-end-position) t)
 	  (delete-region (match-beginning 0) (match-end 0)))
 	(setq p (point))
 	(insert (concat "$B!V$-$g$&$O!"(B" (skk-current-date) "$B$G$9!#!W(B"))
